@@ -13,7 +13,7 @@ Modification History:
 ******************/
 
 /************************************
- Copyright (c) 2000,2001,2002                         RIPE NCC
+ Copyright (c) 2000                              RIPE NCC
 
 All Rights Reserved
 
@@ -42,6 +42,8 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #include <string.h>
 #include <unistd.h>
 
+int num_sources=0;
+
 /* #define DEBUG */
 
 /**********************************************
@@ -458,14 +460,20 @@ ca_readConfig(const char *configFile, values_t confVars[], int size)
  *                                            *
  * Parameters                                    *
  *    configFile -- the configuration file
-  *    confVars[] -- the array of values structures            *
-  *    size -- the number of configuration variables          *
+ *    confVars[] -- the array of values structures            *
+ *    size -- the number of configuration variables          *
  *                                             *
  * Returns                                      *
  *    Nothing -- perhaps make this return 0 on successful exit ?  *
  *                                            *
  * Note:   Should we make the name of the config file a global    *
-  *      variable ?                                *
+ *      variable ?                                *
+
+ *
+ * Using UT_calloc; no need to check that a NULL pointer is
+ * returned.
+ *
+ *
  *******************************************************************/
 {
 	FILE *confPtr;	/* Pointer to config file. */
@@ -543,6 +551,11 @@ int i;		/* A counting variable used for debugging. */
 	printf("Configuration file is: %s\n", configFile);
 #endif	/* DEBUG */
 
+    /* create an aray for the multiple source data pointers */
+    confVars[CA_UPDSOURCE].valPtr = (ca_updDbSource_t **) UT_malloc(CA_MAXSOURCES);
+    /* first entry used to check for at least one valid source found */
+    ((ca_updDbSource_t **)confVars[CA_UPDSOURCE].valPtr)[0] = NULL;
+
 	/*
 	 * Open the configuration file for reading .....
 	 */
@@ -569,7 +582,6 @@ int i;		/* A counting variable used for debugging. */
 	 * file
 	 */
 
-
 	while (!feof(confPtr)) {
 
 		/*
@@ -598,7 +610,7 @@ int i;		/* A counting variable used for debugging. */
 			 * variable.
 			 * 
 			 */
-			location = ca_getStorageLocation(name, dictionary, VARS);
+			location = ca_getStorageLocation(name, dictionary, CA_NUMBEROFSYMBOLS);
 
 #ifdef DEBUG
 			printf("The location is: %d\n", location);
@@ -629,35 +641,10 @@ int i;		/* A counting variable used for debugging. */
 				/*
 				 * Store a pointer to the string that
 				 * contains the value This is not necessarily
-				 * the actual value itself. First, we must
-				 * allocate some memory.
+				 * the actual value itself. 
 				 */
 
-				/******************************************************
-				 * We now use GLib strings here.  Thus, this section 	*
-				 * is commented out.												*
-				 * We use g_string_new() to create a new GString.		*
-				 * 																	*
-				 ******************************************************/
-				 
 				confVars[location].strPtr = g_string_new(value);
-
-				/*
-				 * confVars[location].strPtr = (char *) malloc(STRLENGTH_XXL);
-				 */
-
-				/*
-				 * We check the return value of the malloc
-				 * function .....
-				 */
-	
-				/*
-				 * if (confVars[location].strPtr == NULL) {
-				 *  	fprintf(stderr, "Cannot allocate memory for confVars[location].strPtr\n");
-			    *		die;
-				 *  }
-				 * strcpy(confVars[location].strPtr, value);
-				 */
 			}
 
 			/*
@@ -668,11 +655,11 @@ int i;		/* A counting variable used for debugging. */
 			 * _type_ of the variable.
 			 */
 #ifdef DEBUG
-			printf("Variable \"%s\" is data-type \"%d\"\n", name, ca_getType(name, dictionary, VARS));
+			printf("Variable \"%s\" is data-type \"%d\"\n", name, ca_getType(name, dictionary, CA_NUMBEROFSYMBOLS));
 #endif	/* DEBUG */
 
 
-			type = ca_getType(name, dictionary, VARS);
+			type = ca_getType(name, dictionary, CA_NUMBEROFSYMBOLS);
 
 			/*
 			 * Given the _type_ of the variable, store the value
@@ -687,14 +674,6 @@ int i;		/* A counting variable used for debugging. */
 
 				confVars[location].valPtr = UT_malloc(sizeof(int));
 
-				/*
-				 * We no longer need to do this.
-				 *
-				 * if (confVars[location].valPtr == NULL) {
-				 * fprintf(stderr, "Cannot allocate memory !!!\n");
-           * die;
-    	    * }	
-				 */
 				sscanf(value, "%d", (int *) confVars[location].valPtr);
 				break;
 
@@ -751,15 +730,6 @@ int i;		/* A counting variable used for debugging. */
 #endif	/* DEBUG */
 				confVars[location].valPtr = (char *) UT_malloc(STRLENGTH);
 				
-				/*
-				 * Using UT_malloc => no need to do this.
-				 *
-				 *	if (confVars[location].valPtr == NULL) {
-				 *	fprintf(stderr, "Cannot allocate memory !!!\n");
-				 *	die;
-				 *	}
-				 */
-
 				strcpy(confVars[location].valPtr, value);
 				break;
 
@@ -768,25 +738,8 @@ int i;		/* A counting variable used for debugging. */
 				puts("Data type is Boolean");
 #endif	/* DEBUG */
 
-				/*
-				 * confVars[location].valPtr = (char
-				 * *)malloc(2);
-				 */
-
 				confVars[location].valPtr = UT_malloc(sizeof(int));
 
-				/*
-				 * Using UT_malloc => we do not need to do this.
-				 *
-				 *	if (confVars[location].valPtr == NULL) {
-				 *		fprintf(stderr, "Cannot allocate memory !!!\n");
-				 *		die;
-				 *	}
-				 */
-
-				/*
-				 * strcpy(confVars[location].valPtr, value);
-				 */
 				sscanf(value, "%d", (int *) confVars[location].valPtr);
 				break;
 
@@ -798,17 +751,14 @@ int i;		/* A counting variable used for debugging. */
 				/*
 				 * The elements of the Admin-DB have already
 				 * been read in.
-				 */
-				/*
 				 * Now, split up the elements and assign them
 				 * to the
-				 */
-				/* components of the Admin-DB structure. */
-				/*
+				 * components of the Admin-DB structure. 
+				 *
 				 * First, separate the values in "value",
 				 * using ',' as a
-				 */
-				/* delimiting character.  */
+				 * delimiting character.  
+                 */
 				dbcomps = g_strsplit(value, ",", 0);
 
 #ifdef DEBUG
@@ -822,16 +772,6 @@ int i;		/* A counting variable used for debugging. */
 				 */
 				newAdminPtr = UT_calloc(1, sizeof(ca_ripadmin_t));
 
-				/*
-				 * No need to check that we actually got the memory, 
-				 * because we are using UT_calloc().
-				 *
-			    *	if (newAdminPtr == NULL) {
-			    *		fprintf(stderr, "Cannot allocate memory to new admin-db structure\n");
-			    *		die;
-			    *	}
-				 */
-
 				/*
 				 * Now, assign the elements of the dbcomps
 				 * array to the appropriate components of the
@@ -864,33 +804,9 @@ int i;		/* A counting variable used for debugging. */
 				 * long-term storage.
 				 */
 
-
 				confVars[location].valPtr = (ca_ripadmin_t *) UT_calloc(1, sizeof(ca_ripadmin_t));
 
-
-				/*
-				 * We are using UT_calloc => no need to check that we 
-				 * actually got the memory.
-				 * if (confVars[location].valPtr == NULL) {
-			    *	fprintf(stderr, "Cannot allocate memory to new admin-db structure\n");
-			    *	die;
-			    * }
-				 */
-
 				memcpy(confVars[location].valPtr, newAdminPtr, sizeof(ca_ripadmin_t));
-				/*
-				 * strcpy( ((ca_ripadmin_t
-				 * *)confVars[location].valPtr)->host,
-				 * newAdminPtr->host);
-				 * (confVars[location].valPtr)->port =
-				 * newAdminPtr->port; strcpy(
-				 * (confVars[location].valPtr)->user,
-				 * newAdminPtr->user); strcpy(
-				 * (confVars[location].valPtr)->password,
-				 * newAdminPtr->password); strcpy(
-				 * (confVars[location].valPtr)->tableName,
-				 * newAdminPtr->tableName);
-				 */
 
 				UT_free(newAdminPtr);
 
@@ -903,6 +819,7 @@ int i;		/* A counting variable used for debugging. */
 			case 17:
 				/*
 				 * Found Update_Source variable.
+                   There may be multiple instances of this
 				 */
 #ifdef DEBUG
 				printf("Found Update_Source variable !!!\n");
@@ -947,17 +864,6 @@ int i;		/* A counting variable used for debugging. */
 				 */
 				newUpdDbPtr = UT_calloc(1, sizeof(ca_database_t));
 
-				/*
-				 * Using UT_calloc; no need to check that a NULL pointer is
-				 * returned.
-				 *
-				 *
-				 *	if (newUpdDbPtr == NULL) {
-				 *		fprintf(stderr, "Cannot allocate memory to new UPD DB structure.\n");
-				 *		die;
-				 *	}
-				 */
-
 				strcpy(newUpdDbPtr->host, dbcomps[0]);
 				newUpdDbPtr->port = atoi(dbcomps[1]);
 				strcpy(newUpdDbPtr->user, dbcomps[2]);
@@ -1002,16 +908,6 @@ int i;		/* A counting variable used for debugging. */
 				 */
 				newUpdSrc = UT_calloc(1, sizeof(ca_updDbSource_t));
 
-				/*
-				 * Using calloc; no need to check if a NULL pointer is
-				 * returned.
-				 *
-				 *	if (newUpdSrc == NULL) {
-				 *		fprintf(stderr, "Cannot allocate memory to new source structure\n");
-				 *		die;
-				 *	}
-				 */
-
 #ifdef DEBUG
 				puts("Created a structure for the UPD Source variable");
 #endif	/* DEBUG */
@@ -1041,25 +937,23 @@ int i;		/* A counting variable used for debugging. */
 				 * long-term storage.
 				 */
 
-				confVars[location].valPtr = (ca_updDbSource_t *) UT_calloc(1, sizeof(ca_updDbSource_t));
+                if ( num_sources < CA_MAXSOURCES )
+                {
+				  ((ca_updDbSource_t **)confVars[location].valPtr)[num_sources] = (ca_updDbSource_t *) UT_calloc(1, sizeof(ca_updDbSource_t));
 
-				/*
-				 * No need to check that we actually got the memory, because
-				 * we are using UT_calloc().
-				 *
-			    *	if (confVars[location].valPtr == NULL) {
-			    *		fprintf(stderr, "Cannot allocate memory to new admin-db structure\n");
-			    *		die;
-			    *	}
-				 */
+				  memcpy( ((ca_updDbSource_t **)confVars[location].valPtr)[num_sources++], newUpdSrc, sizeof(ca_updDbSource_t));
+                }
+                else
+                {
+				  fprintf(stderr, "Max number of Update Sources exceeded\n");
+				  die;
+                }
 
-				memcpy(confVars[location].valPtr, newUpdSrc, sizeof(ca_updDbSource_t));
-
-				/* No longer needed. */
-				UT_free(newUpdSrc);
+                /* No longer needed. */
+                UT_free(newUpdSrc);
 
 #ifdef DEBUG
-				printf("UPD-Source/DB-details/user: %s\n", (((ca_updDbSource_t *) confVars[location].valPtr)->updDb).user);
+//				printf("UPD-Source/DB-details/user: %s\n", (((ca_updDbSource_t *) (confVars[location].valPtr)[num_sources-1])->updDb).user);
 #endif	/* DEBUG */
 
 				break;
@@ -1110,7 +1004,8 @@ ca_get_int(int symbol)
 	 */
 #ifdef DEBUG
 	printf("\nDEBUG: ca_get_int() function is called .....\n");
-	printf("DEBUG: New value of StringPtr: %s\n", confVars[symbol].strPtr);
+	printf("DEBUG: New value of StringPtr: %s\n", 
+                    confVars[symbol].strPtr->str ? (char *)(confVars[symbol].strPtr->str) : "NULL");
 #endif	/* DEBUG */
 
 	/*
@@ -1127,6 +1022,7 @@ ca_get_int(int symbol)
 
 #ifdef DEBUG
 	printf("\nDEBUG: Variable type: %s\n", dictionary[symbol].varType);
+	printf("variable: %s\n", dictionary[symbol].varName);
 #endif	/* DEBUG */
 
 	/* If the variable type is not an integer, exit with an error. */
@@ -1248,6 +1144,7 @@ ca_get_string(int symbol)
 	/* If the variable type is not CA_STRING, exit with an error. */
 	if (strcmp(dictionary[symbol].varType, "CA_STRING") != 0) {
 		fprintf(stderr, "Error: unexpected variable type.\n");
+			printf("Error: variable: %s\n", dictionary[symbol].varName);
 		die;
 	}
 	else {
@@ -1306,7 +1203,7 @@ ca_get_boolean(int symbol)
 	 */
 #ifdef DEBUG
 	printf("\nca_get_boolean() function is called .....\n");
-	printf("DEBUG 5: New value of StringPtr: %s\n", globals[symbol].strPtr);
+//	printf("DEBUG 5: New value of StringPtr: %s\n", globals[symbol].strPtr);
 #endif	/* DEBUG  */
 
 	/**********************************************\
@@ -1934,6 +1831,11 @@ ca_srchandle2Strelement(ca_SrcHdl_t * ah, int srcAttrib)
 		myStr = UT_strdup((ah->nrtm).log);
 		break;
 
+  case 18: /* added 24.10.2002 EG */
+    /* trx_support */
+     myStr = UT_strdup((ah->db).trx_support);
+     break;
+
 	default:
 		puts("Cannot find this source attribute");
                 myStr = NULL;
@@ -2040,7 +1942,8 @@ ca_get_adminStrElement(int symbol, int adminAttrib)
 	 * Make sure that we are calling the correct function.
 	 */
 	if (strcmp(dictionary[symbol].varType, "CA_ADMIN") != 0) {
-		fprintf(stderr, "Error: unexpected variable type.\n");
+		fprintf(stderr, "Error: unexpected variable type (%s/%s).\n",
+                  dictionary[symbol].varType, dictionary[symbol].varName);
 		die;
 	}
 	else {
@@ -3194,39 +3097,54 @@ ca_getType(char *confVar, dict_t woordenboek[], int size)
 }
 
 
-ca_updDbSource_t *
+ca_updDbSource_t **
 ca_get_UpdSourceHandle(int symbol)
 /*******************************************************************
- *ca_get_UpdSourceHandle                              *
- * -- returns the handle to the Update source                *
-  *                                            *
-  * Parameters                                    *
-  *  -- none; there is only one Update Source in the Configuration  *
-  *     file because a single DBupdate process cannot update more   *
- *     than one source.                              *
- *                                            *
- * Returns                                      *
-  *  -- a pointer to the Update Source structure (type           *
- *     ca_updDbSource_t) or NULL.                        *
- *                                            *
+ * ca_get_UpdSourceHandle                                          *
+ * -- returns the handle to the Update source                      *
+ *                                                                 *
+ * Parameters                                                      *
+ *  -- none; there is only one Update Source in the Configuration  *
+ *     file because a single DBupdate process cannot update more   *
+ *     than one source.                                            *
+ *     There are now multiple Update Sources in the Configuration  *
+ *     file. This was a self imposed limit that is no longer!!     *
+ *                                                                 *
+ * Returns                                                         *
+ *  -- a pointer to an array of the Update Source structure (type  *
+ *     ca_updDbSource_t) or NULL.                                  *
+ *                                                                 *
  *******************************************************************/
 {
-	ca_updDbSource_t *myUpdSourcePtr;
+	ca_updDbSource_t **myUpdSourcePtr;
 
 	/*
 	 * Make sure that we are calling the correct function.
 	 */
-	if (strcmp(dictionary[symbol].varType, "CA_UPDSOURCE") != 0) {
+	if (strcmp(dictionary[symbol].varType, "CA_UPDSOURCE") != 0) 
+    {
 		fprintf(stderr, "Error: unexpected variable type.\n");
 		die;
 	}
-	else {
-		myUpdSourcePtr = (ca_updDbSource_t *) confVars[symbol].valPtr;
+	else
+    {
+        /* get a pointer to the array of source data pointers */
+		myUpdSourcePtr = (ca_updDbSource_t **) confVars[symbol].valPtr;
 	}
 	return (myUpdSourcePtr);
 }
 
 
+/* returns the number of sources read from the config file 
+   num_sources is declared at the start of this source module
+*/
+
+int ca_get_UpdSourceNum()
+{
+  return num_sources;
+}
+
+
 char *
 ca_UpdSrcHandle2StrElement(ca_updDbSource_t * uh, int srcAttrib)
 /*******************************************************************
@@ -3350,22 +3268,6 @@ ca_UpdSrcHandle2IntElement(ca_updDbSource_t * uh, int srcAttrib)
 
 }
 
-/*
- * void ca_init(dict_t theDict[], const char *configFile, values_t
- * configVars[], int varNo)
- */
-/*
- * ca_init() -- Initialisation function.
- */
-/*
- * { char sourcesFile[80];
- * 
- * ca_populateDictionary(theDict, varNo); ca_readConfig(configFile, configVars,
- * varNo);
- * 
- * sourcesFile = ca_get_dirlist(CA_SOURCEFILE); ca_readSources(sourcesFile,
- * confVars); }
- */
 
 int ca_sanityChk(values_t confVars[])
 /*
@@ -3380,10 +3282,6 @@ int symbol;	/* A counting variable */
 int status = 0;	/* Assume that the Configuration File is complete. */
 int undefVars = 0; /* Number of undefined variables. */
 
-/*
-	* Instead of using VARS here, we use CA_NUMBEROFSYMBOLS.
- *
- */
 for(symbol = 0; symbol < CA_NUMBEROFSYMBOLS; symbol++)
 	{
 	if (!confVars[symbol].strPtr)
