@@ -13,7 +13,7 @@ Modification History:
 ******************/
 
 /************************************
-Copyright (c) 2000,2001,2002                    RIPE NCC
+Copyright (c) 2000                              RIPE NCC
 
 All Rights Reserved
   
@@ -62,9 +62,6 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_whoishelp	ca_get_dirlist(CA_WHOISHELP)
 #define ca_set_whoishelp	ca_set_dirlist(CA_WHOISHELP)
 
-#define ca_get_autodbmhelp	ca_get_dirlist(CA_AUTODBMHELP)
-#define ca_set_autodbmhelp	ca_set_dirlist(CA_AUTODBMHELP)
-
 #define ca_get_attdesc	ca_get_dirlist(CA_ATTDESC)
 #define ca_set_attdesc	ca_set_dirlist(CA_ATTDESC)
 
@@ -77,23 +74,38 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_canupd	ca_get_source(CA_CANUPD)
 #define ca_set_canupd	ca_set_source(CA_CANUPD)
 
-#define ca_get_crossnotifysources	ca_get_source(CA_CROSSNOTIFYSOURCES)
-#define ca_set_crossnotifysources	ca_set_source(CA_CROSSNOTIFYSOURCES)
-
 #define ca_get_uid	ca_get_int(CA_UID)
 #define ca_set_uid	ca_set_int(CA_UID)
 
 #define ca_get_qrylog	ca_get_dirlist(CA_QRYLOG)
 #define ca_set_qrylog	ca_set_dirlist(CA_QRYLOG)
 
+#define ca_get_ripmirlog	ca_get_dirlist(CA_RIPMIRLOG)
+#define ca_set_ripmirlog	ca_set_dirlist(CA_RIPMIRLOG)
+
+#define ca_get_ripsvrlog	ca_get_dirlist(CA_RIPSVRLOG)
+#define ca_set_ripsvrlog	ca_set_dirlist(CA_RIPSVRLOG)
+
+#define ca_get_sqlog	ca_get_dirlist(CA_SQLOG)
+#define ca_set_sqlog	ca_set_dirlist(CA_SQLOG)
+
 #define ca_get_qry2log	ca_get_dirlist(CA_QRY2LOG)
 #define ca_set_qry2log	ca_set_dirlist(CA_QRY2LOG)
 
 #define ca_get_errlog	ca_get_dirlist(CA_ERRLOG)
 #define ca_set_errlog	ca_set_dirlist(CA_ERRLOG)
 
-#define ca_get_auditlog	ca_get_dirlist(CA_AUDITLOG)
-#define ca_set_auditlog	ca_set_dirlist(CA_AUDITLOG)
+#define ca_get_ripaudit	ca_get_dirlist(CA_RIPAUDIT)
+#define ca_set_ripaudit	ca_set_dirlist(CA_RIPAUDIT)
+
+#define ca_get_dberrlog       ca_get_dirlist(CA_DBUPERR)
+#define ca_set_dberrlog       ca_set_dirlist(CA_DBUPERR)
+
+#define ca_get_allriperr	ca_get_dirlist(CA_ALLRIPERR)
+#define ca_set_allriperr	ca_set_dirlist(CA_ALLRIPERR)
+
+#define ca_get_ripupdlog	ca_get_dirlist(CA_RIPUPDLOG)
+#define ca_set_ripupdlog	ca_set_dirlist(CA_RIPUPDLOG)
 
 #define ca_get_updlog	ca_get_dirlist(CA_UPDLOG)
 #define ca_set_updlog	ca_set_dirlist(CA_UPDLOG)
@@ -101,6 +113,11 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_acklog	ca_get_dirlist(CA_ACKLOG)
 #define ca_set_acklog	ca_set_dirlist(CA_ACKLOG)
 
+#define ca_get_ack_template	ca_get_dirlist(CA_ACKTEMPLATE)
+#define ca_get_notif_template	ca_get_dirlist(CA_NOTIFTEMPLATE)
+#define ca_get_frwd_template	ca_get_dirlist(CA_FRWDTEMPLATE)
+#define ca_get_forw_create_template	ca_get_dirlist(CA_FORWCREATETEMPLATE)
+
 #define ca_get_lockdir	ca_get_dirlist(CA_LOCKDIR)
 #define ca_set_lockdir	ca_set_dirlist(CA_LOCKDIR)
 
@@ -131,9 +148,6 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_getupdatesfrom	ca_get_string(CA_GETUPDATESFROM)
 #define ca_set_getupdatesfrom	ca_set_string(CA_GETUPDATESFROM)
 
-#define ca_get_whoisupdfrom	ca_get_string(CA_WHOISUPDFROM)
-#define ca_set_whoisupdfrom	ca_set_string(CA_WHOISUPDFROM)
-
 #define ca_get_denywhoisaccess	ca_get_string(CA_DENYWHOISACCESS)
 #define ca_set_denywhoisaccess	ca_set_string(CA_DENYWHOISACCESS)
 
@@ -167,105 +181,12 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_autobox	ca_get_string(CA_AUTOBOX)
 #define ca_set_autobox	ca_set_string(CA_AUTOBOX)
 
-#define ca_get_duplicatepersoncheck	ca_get_string(CA_DUPLICATEPERSONCHECK)
-#define ca_set_duplicatepersoncheck	ca_set_string(CA_DUPLICATEPERSONCHECK)
-
 #define ca_get_replybanner	ca_get_string(CA_REPLYBANNER)
 #define ca_set_replybanner	ca_set_string(CA_REPLYBANNER)
 
 #define ca_get_nomatch	ca_get_string(CA_NOMATCH)
 #define ca_set_nomatch	ca_set_string(CA_NOMATCH)
 
-#define ca_get_cn_subject_add	ca_get_string(CA_CN_SUBJECT_ADD)
-#define ca_set_cn_subject_add	ca_set_string(CA_CN_SUBJECT_ADD)
-
-#define ca_get_cn_subject_del	ca_get_string(CA_CN_SUBJECT_DEL)
-#define ca_set_cn_subject_del	ca_set_string(CA_CN_SUBJECT_DEL)
-
-#define ca_get_cn_explain_add	ca_get_string(CA_CN_EXPLAIN_ADD)
-#define ca_set_cn_explain_add	ca_set_string(CA_CN_EXPLAIN_ADD)
-
-#define ca_get_cn_explain_del	ca_get_string(CA_CN_EXPLAIN_DEL)
-#define ca_set_cn_explain_del	ca_set_string(CA_CN_EXPLAIN_DEL)
-
-#define ca_get_cn_overlap_add	ca_get_string(CA_CN_OVERLAP_ADD)
-#define ca_set_cn_overlap_add	ca_set_string(CA_CN_OVERLAP_ADD)
-
-#define ca_get_cn_overlap_del	ca_get_string(CA_CN_OVERLAP_DEL)
-#define ca_set_cn_overlap_del	ca_set_string(CA_CN_OVERLAP_DEL)
-
-#define ca_get_cno_subject_add	ca_get_string(CA_CNO_SUBJECT_ADD)
-#define ca_set_cno_subject_add	ca_set_string(CA_CNO_SUBJECT_ADD)
-
-#define ca_get_cno_subject_del	ca_get_string(CA_CNO_SUBJECT_DEL)
-#define ca_set_cno_subject_del	ca_set_string(CA_CNO_SUBJECT_DEL)
-
-#define ca_get_cno_explain_add	ca_get_string(CA_CNO_EXPLAIN_ADD)
-#define ca_set_cno_explain_add	ca_set_string(CA_CNO_EXPLAIN_ADD)
-
-#define ca_get_cno_explain_del	ca_get_string(CA_CNO_EXPLAIN_DEL)
-#define ca_set_cno_explain_del	ca_set_string(CA_CNO_EXPLAIN_DEL)
-
-#define ca_get_cno_overlap_add	ca_get_string(CA_CNO_OVERLAP_ADD)
-#define ca_set_cno_overlap_add	ca_set_string(CA_CNO_OVERLAP_ADD)
-
-#define ca_get_cno_overlap_del	ca_get_string(CA_CNO_OVERLAP_DEL)
-#define ca_set_cno_overlap_del	ca_set_string(CA_CNO_OVERLAP_DEL)
-
-#define ca_get_mailtxt	ca_get_string(CA_MAILTXT)
-#define ca_set_mailtxt	ca_set_string(CA_MAILTXT)
-
-#define ca_get_mheader	ca_get_string(CA_MHEADER)
-#define ca_set_mheader	ca_set_string(CA_MHEADER)
-
-#define ca_get_failuretxt	ca_get_string(CA_FAILURETXT)
-#define ca_set_failuretxt	ca_set_string(CA_FAILURETXT)
-
-#define ca_get_successtxt	ca_get_string(CA_SUCCESSTXT)
-#define ca_set_successtxt	ca_set_string(CA_SUCCESSTXT)
-
-#define ca_get_helpheader	ca_get_string(CA_HELPHEADER)
-#define ca_set_helpheader	ca_set_string(CA_HELPHEADER)
-
-#define ca_get_ackerr	ca_get_string(CA_ACKERR)
-#define ca_set_ackerr	ca_set_string(CA_ACKERR)
-
-#define ca_get_ackok	ca_get_string(CA_ACKOK)
-#define ca_set_ackok	ca_set_string(CA_ACKOK)
-
-#define ca_get_acksig	ca_get_string(CA_ACKSIG)
-#define ca_set_acksig	ca_set_string(CA_ACKSIG)
-
-#define ca_get_notitxt	ca_get_string(CA_NOTITXT)
-#define ca_set_notitxt	ca_set_string(CA_NOTITXT)
-
-#define ca_get_notimailtxt	ca_get_string(CA_NOTIMAILTXT)
-#define ca_set_notimailtxt	ca_set_string(CA_NOTIMAILTXT)
-
-#define ca_get_notinetworktxt	ca_get_string(CA_NOTINETWORKTXT)
-#define ca_set_notinetworktxt	ca_set_string(CA_NOTINETWORKTXT)
-
-#define ca_get_nheader	ca_get_string(CA_NHEADER)
-#define ca_set_nheader	ca_set_string(CA_NHEADER)
-
-#define ca_get_fwheader	ca_get_string(CA_FWHEADER)
-#define ca_set_fwheader	ca_set_string(CA_FWHEADER)
-
-#define ca_get_fwtxt	ca_get_string(CA_FWTXT)
-#define ca_set_fwtxt	ca_set_string(CA_FWTXT)
-
-#define ca_get_fwmailtxt	ca_get_string(CA_FWMAILTXT)
-#define ca_set_fwmailtxt	ca_set_string(CA_FWMAILTXT)
-
-#define ca_get_fwnetworktxt	ca_get_string(CA_FWNETWORKTXT)
-#define ca_set_fwnetworktxt	ca_set_string(CA_FWNETWORKTXT)
-
-#define ca_get_mtfwheader	ca_get_string(CA_MTFWHEADER)
-#define ca_set_mtfwheader	ca_set_string(CA_MTFWHEADER)
-
-#define ca_get_mtfwtxt	ca_get_string(CA_MTFWTXT)
-#define ca_set_mtfwtxt	ca_set_string(CA_MTFWTXT)
-
 #define ca_get_denyaccesstxt	ca_get_string(CA_DENYACCESSTXT)
 #define ca_set_denyaccesstxt	ca_set_string(CA_DENYACCESSTXT)
 
@@ -296,6 +217,9 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_rights	ca_get_string(CA_RIGHTS)
 #define ca_set_rights	ca_set_string(CA_RIGHTS)
 
+#define ca_get_nicsuffix	ca_get_string(CA_NICSUFFIX)
+#define ca_set_nicsuffix	ca_set_string(CA_NICSUFFIX)
+
 #define ca_get_country	ca_get_string(CA_COUNTRY)
 #define ca_set_country	ca_set_string(CA_COUNTRY)
 
@@ -320,6 +244,9 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 #define ca_get_srcdbport(X) ca_srchandle2Intelement((X), CA_DBPORT)
 
+/* the following added 25/10/2002 EG */
+#define ca_get_srctrx_support(X) ca_srchandle2Strelement((X), CA_DBTRX_SUPPORT)
+
 #define ca_get_srcnrtmhost(X) ca_srchandle2Strelement((X), CA_NRTMHOST)
 
 #define ca_get_srcnrtmlog(X) ca_srchandle2Strelement((X), CA_NRTMLOG)
@@ -340,9 +267,6 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_forwlog  ca_get_dirlist(CA_FORWLOG)
 #define ca_set_forwlog  ca_set_dirlist(CA_FORWLOG)
 
-#define ca_get_crosslog ca_get_dirlist(CA_CROSSLOG)
-#define ca_set_crosslog ca_set_dirlist(CA_CROSSLOG)
-
 #define ca_get_ripadminport ca_get_adminIntElement(CA_RIPADMIN, CA_ADMINPORT)
 #define ca_get_ripadminuser ca_get_adminStrElement(CA_RIPADMIN, CA_ADMINUSER)
 
@@ -403,20 +327,26 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_pw_err_nokey	ca_get_string(CA_PW_ERR_NOKEY)
 #define ca_set_pw_err_nokey	ca_set_string(CA_PW_ERR_NOKEY)
 
+#define ca_get_pw_err_linetoolong	ca_get_string(CA_PW_ERR_LINETOOLONG)
+#define ca_set_pw_err_linetoolong	ca_set_string(CA_PW_ERR_LINETOOLONG)
+
 #define ca_get_pw_help_file	ca_get_dirlist(CA_PW_HELP_FILE)
 #define ca_set_pw_help_file	ca_set_dirlist(CA_PW_HELP_FILE)
 
 #define ca_get_pw_k_filter	ca_get_string(CA_PW_K_FILTER)
 #define ca_set_pw_k_filter	ca_set_string(CA_PW_K_FILTER)
 
-#define ca_get_pw_limit_reached	ca_get_string(CA_PW_LIMIT_REACHED)
-#define ca_set_pw_limit_reached	ca_set_string(CA_PW_LIMIT_REACHED)
+#define ca_get_pw_fmt_limit_reached	ca_get_string(CA_PW_FMT_LIMIT_REACHED)
+#define ca_set_pw_fmt_limit_reached	ca_set_string(CA_PW_FMT_LIMIT_REACHED)
 
-#define ca_get_pw_acl_addrpass	ca_get_string(CA_PW_ACL_ADDRPASS)
-#define ca_set_pw_acl_addrpass	ca_set_string(CA_PW_ACL_ADDRPASS)
+#define ca_get_pw_fmt_acl_addrpass	ca_get_string(CA_PW_FMT_ACL_ADDRPASS)
+#define ca_set_pw_fmt_acl_addrpass	ca_set_string(CA_PW_FMT_ACL_ADDRPASS)
 
-#define ca_get_pw_acl_permdeny	ca_get_string(CA_PW_ACL_PERMDENY)
-#define ca_set_pw_acl_permdeny	ca_set_string(CA_PW_ACL_PERMDENY)
+#define ca_get_pw_fmt_acl_permdeny	ca_get_string(CA_PW_FMT_ACL_PERMDENY)
+#define ca_set_pw_fmt_acl_permdeny	ca_set_string(CA_PW_FMT_ACL_PERMDENY)
+
+#define ca_get_pw_fmt_acl_conndeny	ca_get_string(CA_PW_FMT_ACL_CONNDENY)
+#define ca_set_pw_fmt_acl_conndeny	ca_set_string(CA_PW_FMT_ACL_CONNDENY)
 
 #define ca_get_pw_notfound	ca_get_string(CA_PW_NOTFOUND)
 #define ca_set_pw_notfound	ca_set_string(CA_PW_NOTFOUND)
@@ -427,8 +357,8 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_pw_banner	ca_get_string(CA_PW_BANNER)
 #define ca_set_pw_banner	ca_set_string(CA_PW_BANNER)
 
-#define ca_get_qc_badattr	ca_get_string(CA_QC_BADATTR)
-#define ca_set_qc_badattr	ca_set_string(CA_QC_BADATTR)
+#define ca_get_qc_fmt_badattr	ca_get_string(CA_QC_FMT_BADATTR)
+#define ca_set_qc_fmt_badattr	ca_set_string(CA_QC_FMT_BADATTR)
 
 #define ca_get_qc_fmt_attrnotinv	ca_get_string(CA_QC_FMT_ATTRNOTINV)
 #define ca_set_qc_fmt_attrnotinv	ca_set_string(CA_QC_FMT_ATTRNOTINV)
@@ -436,8 +366,26 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_qc_fmt_badsource	ca_get_string(CA_QC_FMT_BADSOURCE)
 #define ca_set_qc_fmt_badsource	ca_set_string(CA_QC_FMT_BADSOURCE)
 
-#define ca_get_qc_badobjtype	ca_get_string(CA_QC_BADOBJTYPE)
-#define ca_set_qc_badobjtype	ca_set_string(CA_QC_BADOBJTYPE)
+#define ca_get_qc_fmt_badobjtype	ca_get_string(CA_QC_FMT_BADOBJTYPE)
+#define ca_set_qc_fmt_badobjtype	ca_set_string(CA_QC_FMT_BADOBJTYPE)
+
+#define ca_get_qc_fmt_dupipflag	ca_get_string(CA_QC_FMT_DUPIPFLAG)
+#define ca_set_qc_fmt_dupipflag	ca_set_string(CA_QC_FMT_DUPIPFLAG)
+
+#define ca_get_qc_dupproxyipflag	ca_get_string(CA_QC_DUPPROXYIPFLAG)
+#define ca_set_qc_dupproxyipflag	ca_set_string(CA_QC_DUPPROXYIPFLAG)
+
+#define ca_get_qc_badinput	ca_get_string(CA_QC_BADINPUT)
+#define ca_set_qc_badinput	ca_set_string(CA_QC_BADINPUT)
+
+#define ca_get_qc_uselessipflag	ca_get_string(CA_QC_USELESSIPFLAG)
+#define ca_set_qc_uselessipflag	ca_set_string(CA_QC_USELESSIPFLAG)
+
+#define ca_get_qc_uselessnorefflag	ca_get_string(CA_QC_USELESSNOREFFLAG)
+#define ca_set_qc_uselessnorefflag	ca_set_string(CA_QC_USELESSNOREFFLAG)
+
+#define ca_get_qc_fmt_fixedlookup	ca_get_string(CA_QC_FMT_FIXEDLOOKUP)
+#define ca_set_qc_fmt_fixedlookup	ca_set_string(CA_QC_FMT_FIXEDLOOKUP)
 
 #define ca_get_qi_ref_tmout	ca_get_string(CA_QI_REF_TMOUT)
 #define ca_set_qi_ref_tmout	ca_set_string(CA_QI_REF_TMOUT)
@@ -454,12 +402,6 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define ca_get_qi_fmt_refheader	ca_get_string(CA_QI_FMT_REFHEADER)
 #define ca_set_qi_fmt_refheader	ca_set_string(CA_QI_FMT_REFHEADER)
 
-#define ca_get_er_def	ca_get_string(CA_ER_DEF)
-#define ca_set_er_def	ca_set_string(CA_ER_DEF)
-
-#define ca_get_er_macro	ca_get_string(CA_ER_MACRO)
-#define ca_set_er_macro	ca_set_string(CA_ER_MACRO)
-
 #define ca_get_er_ud_def	ca_get_dirlist(CA_ER_UD_DEF)
 #define ca_set_er_ud_def	ca_set_dirlist(CA_ER_UD_DEF)
 
