@@ -14,7 +14,7 @@ Modification History:
 ******************/
 
 /************************************
-Copyright (c) 2000,2001                         RIPE NCC
+Copyright (c) 2000                              RIPE NCC
 
 All Rights Reserved
 
@@ -206,13 +206,13 @@ int no_source_defd;
 #ifdef DEBUG
 				puts("We have reached the end of a DATABASE definition");
 				puts("Testing the population of the db structure:");
-				printf("\n%s::%d::%s::%s::%s\n", newDbPtr->host, newDbPtr->port, newDbPtr->user, newDbPtr->password, newDbPtr->dbName);
+				printf("\n%s::%d::%s::%s::%s::%s\n", newDbPtr->host, newDbPtr->port, newDbPtr->trx_support, newDbPtr->user, newDbPtr->password, newDbPtr->dbName);
 #endif	/* DEBUG */
 
 			/*
 			 * Check that the definition of the DATABASE is complete.
 			 */
-			 if ( !(newDbPtr->host && newDbPtr->port && newDbPtr->user && newDbPtr->password && newDbPtr->dbName) )
+			 if ( !(newDbPtr->host && newDbPtr->port && newDbPtr->trx_support && newDbPtr->user && newDbPtr->password && newDbPtr->dbName) )
 				{
 				fprintf(stderr, "Error: definition of database is incomplete.\n");
 				die;
@@ -417,7 +417,7 @@ int no_source_defd;
 				puts("We have reached the end of a SOURCE definition");
 				puts("Testing the population of the new Source structure:");
 				printf("Source name: %s\n", newSrcPtr->name);
-				printf("\nDB == %s::%d::%s::%s::%s\n", (newSrcPtr->db).host, (newSrcPtr->db).port, (newSrcPtr->db).user, (newSrcPtr->db).password, (newSrcPtr->db).dbName);
+				printf("\nDB == %s::%d::%s::%s::%s::%s\n", (newSrcPtr->db).host, (newSrcPtr->db).port, (newSrcPtr->db).trx_support, (newSrcPtr->db).user, (newSrcPtr->db).password, (newSrcPtr->db).dbName);
 				printf("Mode: %d\n", newSrcPtr->opMode);
 				printf("NRTM == %s::%d::%d:%d\n", (newSrcPtr->nrtm).host, (newSrcPtr->nrtm).port, (newSrcPtr->nrtm).delay, (newSrcPtr->nrtm).protocolVer);
 				printf("UpdPort: %d\n", newSrcPtr->updPort);
@@ -545,7 +545,7 @@ ca_getAllDatabases(GSList * databases)
 	 */
 	while (currentPtr != NULL) {
 		ca_database_t *dbPtr = currentPtr->data;
-		printf("\n%s,%d,%s,%s,%s\n", dbPtr->host, dbPtr->port, dbPtr->user, dbPtr->password, dbPtr->dbName);
+		printf("\n%s,%d,%s,%s,%s,%s\n", dbPtr->host, dbPtr->port, dbPtr->trx_support, dbPtr->user, dbPtr->password, dbPtr->dbName);
 		currentPtr = currentPtr->next;
 	}
 }
@@ -634,16 +634,21 @@ ca_parseDbLine(char *lineStr, ca_database_t * dbStructPtr)
 			dbStructPtr->port = atoi(dbComp);
 		}
 		else {
-			if (strcmp(varName, "user") == 0) {
-				strcpy(dbStructPtr->user, dbComp);
-			}
-			else {
-				if (strcmp(varName, "password") == 0) {
-					strcpy(dbStructPtr->password, dbComp);
-				}
-				else {
-					fprintf(stderr, "Unknown database component \"%s\".\n", dbComp);
-					die;
+      if (strcmp(varName, "user") == 0) {
+        strcpy(dbStructPtr->user, dbComp);
+      }
+      else {
+        if (strcmp(varName, "trx_support") == 0) { /* added 24.10.2002 EG */
+          strcpy(dbStructPtr->trx_support, dbComp);
+        }
+        else {
+          if (strcmp(varName, "password") == 0) {
+            strcpy(dbStructPtr->password, dbComp);
+          }
+          else {
+            fprintf(stderr, "Unknown database component \"%s\".\n", dbComp);
+            die;
+          }
 				}
 			}
 		}
