@@ -2,7 +2,7 @@
 #define READ_DEFS
 
 /***************************************
-  $Revision: 1.16 $
+  $Revision: 1.18 $
 
   Objects module (ob) - this _should_ eventually get merged in with the
   config module.
@@ -10,7 +10,7 @@
   Status: NOT REVUED, NOT TESTED
 
   ******************/ /******************
-  Copyright (c) 1999,2000,2001,2002               RIPE NCC
+  Copyright (c) 1999                              RIPE NCC
  
   All Rights Reserved
   
@@ -120,7 +120,6 @@ char * const *DF_get_class_names(void);
 char * const *DF_get_class_aliases(void);
 char * const *DF_get_attribute_aliases(void);
 char * const *DF_get_attribute_names(void);
-char * const *DF_get_server_queries(void);
 
 
 /* take class type enum, return the corresponding string  */
@@ -164,7 +163,6 @@ char * DF_attrcode_radix_load_v6(A_Type_t attr);
 /* take string, return corresponding enum code */
 A_Type_t DF_attribute_code2type(const gchar *token);
 A_Type_t DF_attribute_name2type (const gchar *token);
-C_Type_t DF_class_code2type(const gchar *token);
 C_Type_t DF_class_name2type(const gchar *token);
 
 #endif /* READ_DEFS */
