@@ -1,5 +1,7 @@
 /***************************************
-  $Revision: 1.11 $
+  $Revision: 1.17 $
+
+  NIC handle manipulation module.
 
   Status: NOT REVUED, NOT TESTED
 
@@ -9,7 +11,7 @@
   Modification History:
         andrei (10/04/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000                              RIPE NCC
+  Copyright (c) 2000,2001,2002,2003               RIPE NCC
  
   All Rights Reserved
   
@@ -28,6 +30,9 @@
   AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ***************************************/
+
+#include "rip.h"
+
 #include <glib.h>
 #include <stdio.h>
 #include <strings.h>
@@ -36,10 +41,6 @@
 #include <ctype.h>
 #include <unistd.h>
 
-#include "nh.h"
-#include "memwrap.h"
-#include "stubs.h"
-
 /*+ String sizes +*/
 #define STR_S   63
 #define STR_M   255
@@ -84,9 +85,6 @@ char *NH_convert(nic_handle_t *nh_ptr)
  char *nic_components[4];
  char *nic_handle;
  int nc=0;
-  
-  if(nh_ptr == NULL) return(NULL);
-  
   /* Check for special cases */
   /* Is is and AUTO nic-handle ? */
   if(nh_ptr->nic_id == AUTO_NIC_ID) return(NULL);
@@ -125,35 +123,37 @@ char *NH_convert(nic_handle_t *nh_ptr)
 * -1  - error                                               *
 *                                                           *
 ************************************************************/
-int NH_parse(char *nic, nic_handle_t **nh_ptr_ptr)
+int NH_parse(const char *nic, nic_handle_t **nh_ptr_ptr)
 {
-char *ptr;
+const char *ptr;
 int res = 1;
 nic_handle_t *nh_ptr;
 
-     if(!(nh_ptr=calloc(1, sizeof(nic_handle_t)))) die;
      *nh_ptr_ptr=NULL;
+     if(!(nh_ptr=UT_calloc(1, sizeof(nic_handle_t)))) die;
      
      ptr=nic;	
 
      /* extract space */
      while(isalpha((int)*ptr))ptr++;
-     /*XXX sanity check - space <=4 characters */
+
+     /* sanity check - space <=4 characters */
      if((ptr-nic)>MAX_NH_SPACE_LENGTH) {
-	     UT_free(nh_ptr);
-	     return(-1);
+       UT_free(nh_ptr);
+       return(-1);
      }
-     if(!(nh_ptr->space=malloc(ptr-nic+1))) die;
+
+     if(!(nh_ptr->space=UT_malloc(ptr-nic+1))) die;
      strncpy(nh_ptr->space, nic, ptr-nic); *(nh_ptr->space+(ptr-nic))='\0';
 
-     /* If there are no digits, then this is a 'no' nic-hdl */
+     /* If there are no digits, then this is no nic-hdl */
      /* We reserve NULL_NIC_ID for such pretty identifiers */
      if(*ptr == '\0') {
        nh_ptr->nic_id=NULL_NIC_ID;
        nh_ptr->source=NULL;
      }
      else {
-       /* Check if it is an AUTO nic */
+       /* Check if it is and AUTO nic */
        if (*ptr == '*') {
 	       /* For AUTO nic_id we reserve AUTO_NIC_ID */
 	       nh_ptr->nic_id=AUTO_NIC_ID;
@@ -162,29 +162,32 @@ nic_handle_t *nh_ptr;
        } else {
          nic=ptr;
 	 /* convert digits (if any) and store first invalid characted in ptr */
-         nh_ptr->nic_id=(int)strtol(nic, &ptr, 10);
-	 /* Check if there were any digits at all */
-	 if(ptr == nic) nh_ptr->nic_id=NULL_NIC_ID;
+         if(isdigit((int)*nic)){
+             nh_ptr->nic_id=(int)strtol(nic, (char **)&ptr, 10);
+         } else {    
+	     /* There were no digits at all */
+	     nh_ptr->nic_id=NULL_NIC_ID;
+         }    
        }
-       /*XXX sanity check - if the ID does not exeed NH_MAX_ID */
+       /* sanity check - if the ID does not exeed NH_MAX_ID */
        if(nh_ptr->nic_id > MAX_NIC_ID) {
-	       if(nh_ptr) {
-                UT_free(nh_ptr->source);UT_free(nh_ptr);
-               }
-	       return(-1);
+         if(nh_ptr) {
+           UT_free(nh_ptr->space);UT_free(nh_ptr);
+         }
+         return(-1);
        }
        /* check if there is any suffix */
        if (*ptr == '\0') nh_ptr->source=NULL;
        /* Copy suffix into source */
        else {
-	 /*XXX sanity check - suffix does not exceed the length */
-	 if(strlen(ptr)>MAX_NH_SOURCE_LENGTH) {
-		 if(nh_ptr){
-                   UT_free(nh_ptr->source);UT_free(nh_ptr);
-                  }
-		 return(-1);
-	 }
-	 if(!(nh_ptr->source=malloc(strlen(ptr)+1))) die;
+         /* sanity check - suffix does not exceed the length */
+         if(strlen(ptr)>MAX_NH_SOURCE_LENGTH) {
+             if(nh_ptr){
+               UT_free(nh_ptr->space);UT_free(nh_ptr);
+             }
+             return(-1);
+         }
+	 if(!(nh_ptr->source=UT_malloc(strlen(ptr)+1))) die;
 	 strcpy(nh_ptr->source, ptr);
        }
      } 
@@ -210,14 +213,9 @@ int NH_check(nic_handle_t *nh_ptr, SQ_connection_t *sql_connection)
 {
 range_t range;
 long range_id;
-long nic_id;
+long nic_id=nh_ptr->nic_id;
 
 
-  /* this can happen if nic handle is incorrect, NH_parse will null the structure */
-  if( nh_ptr == NULL) return(0);
-
-  nic_id=nh_ptr->nic_id;
-
   range.space=nh_ptr->space;
   if(nh_ptr->source)range.source=nh_ptr->source; else range.source="";
   
@@ -265,13 +263,9 @@ int NH_free(nic_handle_t *nh_ptr, SQ_connection_t *sql_connection, int commit_no
 range_t range;
 long range_id;
 int old_start;
-long nic_id;
+long nic_id=nh_ptr->nic_id;
 
 
-  if(nh_ptr == NULL) return(0);
-
-  nic_id=nh_ptr->nic_id;
-  
   range.space=nh_ptr->space;
   if(nh_ptr->source)range.source=nh_ptr->source; else range.source="";
   
@@ -319,8 +313,7 @@ long nic_id;
 *                                                           *
 * Returns:                                                  *
 * 1 - success                                               *
-* 0  - wrong nic handle, nic_id already exists or           * 
-*      space is fully occupied                              *
+* 0  - nic_id already exists or space is fully occupied     *
 * -1 - error (f.e. more than one object with the same PK)   *
 *                                                           *
 ************************************************************/
@@ -328,12 +321,10 @@ int NH_register(nic_handle_t *nh_ptr, SQ_connection_t *sql_connection, int commi
 {
 range_t range;
 long range_id;
-long nic_id;
+long nic_id=nh_ptr->nic_id;
 
 
-  if(nh_ptr == NULL) return(0);
 
-  nic_id=nh_ptr->nic_id;
 
  /* Yiu should check for nh first for AUTO nic-handles */
   if (nic_id == AUTO_NIC_ID) { return(0); };
@@ -382,8 +373,8 @@ long nic_id;
 void free_nh(nic_handle_t *nh_ptr)
 {
  if(nh_ptr){
-   if(nh_ptr->space)UT_free(nh_ptr->space);
-   if(nh_ptr->source)free(nh_ptr->source);
+   if(nh_ptr->space) UT_free(nh_ptr->space);
+   if(nh_ptr->source) UT_free(nh_ptr->source);
    UT_free(nh_ptr);
  }
 }
@@ -413,10 +404,7 @@ GString *query;
 long range_id=0;
 int sql_err;
 
- if ((query = g_string_sized_new(STR_L)) == NULL){ 
-  fprintf(stderr, "E: cannot allocate gstring\n"); 
-  return(-1); 
- }
+ query = g_string_sized_new(STR_L);
  
 /* Define row numbers in the result of the query */
 #define RANGE_ID 0
@@ -512,11 +500,7 @@ long prev_range_id, next_range_id;
 int num;
 int sql_err;
 
-/* Allocate memory */
- if ((query = g_string_sized_new(STR_L)) == NULL){ 
-  fprintf(stderr, "E: cannot allocate gstring\n"); 
-  return(-1); 
- }
+ query = g_string_sized_new(STR_L);
 
 /* Do range check */
  if (( p_newrange->end > MAX_RANGE ) || ( p_newrange->start < MIN_RANGE )) return(-1);
@@ -676,11 +660,7 @@ GString *query;
 int sql_err, num;
 long range_id;
 
- /* Allocate memory */
- if ((query = g_string_sized_new(STR_L)) == NULL){ 
-  fprintf(stderr, "E: cannot allocate gstring\n"); 
-  return(-1); 
- }
+ query = g_string_sized_new(STR_L);
  
  /* get the next range_id */
  /* XXX we cannot use autoincrement with MyISAM tables */
@@ -730,11 +710,7 @@ int NH_comrol(SQ_connection_t *sql_connection, int thread_ins, int thread_del)
 GString *query;
 int sql_err;
 
- /* Allocate memory */
- if ((query = g_string_sized_new(STR_L)) == NULL){ 
-  fprintf(stderr, "E: cannot allocate gstring\n"); 
-  return(-1); 
- }
+ query = g_string_sized_new(STR_L);
  
   g_string_sprintf(query, "DELETE FROM nic_hdl "
 			  "WHERE thread_id=%d ",
