@@ -1,15 +1,17 @@
 /***************************************
-  $Revision: 1.4 $
+  $Revision: 1.8 $
+
+  NIC handle manipulation module.
 
   Status: NOT REVUED, NOT TESTED
 
- Author(s):       Andrei Robachevsky
+  Author(s):       Andrei Robachevsky
 
   ******************/ /******************
   Modification History:
         andrei (10/04/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000                              RIPE NCC
+  Copyright (c) 2000,2001,2002,2003               RIPE NCC
  
   All Rights Reserved
   
@@ -75,7 +77,7 @@ int NH_free(nic_handle_t *pnh, SQ_connection_t *sql_connection, int commit_now);
 int NH_register(nic_handle_t *pnh, SQ_connection_t *sql_connection, int commit_now);
 
 char *NH_convert(nic_handle_t *pnh);
-int NH_parse(char *nic, nic_handle_t **pnh);
+int NH_parse(const char *nic, nic_handle_t **pnh);
 
 void free_nh(nic_handle_t *nh_ptr);
 
