@@ -1,5 +1,5 @@
 /******************
-  Copyright (c) 2002                                        RIPE NCC
+  Copyright (c) 2002                              RIPE NCC
 
   All Rights Reserved
 
@@ -26,9 +26,11 @@ int command_help(char *input, GString *output, sk_conn_st *condat);
 int command_purify(char *input, GString *output, sk_conn_st *condat);
 int command_quit(char *input, GString *output, sk_conn_st *condat);
 int command_set(char *input, GString *output, sk_conn_st *condat);
+int command_save(char *input, GString *output, sk_conn_st *condat);
 int command_show(char *input, GString *output, sk_conn_st *condat);
 int command_stop(char *input, GString *output, sk_conn_st *condat);
 int set_acl(char *input, GString *output, sk_conn_st *condat);
+int set_auto_save(char *input, GString *output, sk_conn_st *condat);
 int set_const(char *input, GString *output, sk_conn_st *condat);
 int set_consts(char *input, GString *output, sk_conn_st *condat);
 int set_counter(char *input, GString *output, sk_conn_st *condat);
@@ -39,8 +41,10 @@ int set_props(char *input, GString *output, sk_conn_st *condat);
 int set_updates(char *input, GString *output, sk_conn_st *condat);
 int set_queries(char *input, GString *output, sk_conn_st *condat);
 int set_initrx(char *input, GString *output, sk_conn_st *condat);
+int save_access_tree(char *input, GString *output, sk_conn_st *condat);
 int show_access(char *input, GString *output, sk_conn_st *condat);
 int show_acl(char *input, GString *output, sk_conn_st *condat);
+int show_auto_save(char *input, GString *output, sk_conn_st *condat);
 int show_const(char *input, GString *output, sk_conn_st *condat);
 int show_consts(char *input, GString *output, sk_conn_st *condat);
 int show_err(char *input, GString *output, sk_conn_st *condat);
