@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.96 $
+  $Revision: 1.100 $
 
   Query instructions (qi).  This is where the queries are executed.
 
@@ -12,7 +12,7 @@
 			accounting support and watchdog cancellation.
   OSs Tested          : Solaris
   ******************/ /******************
-  Copyright (c) 1999,2000,2001,2002               RIPE NCC
+  Copyright (c) 1999                              RIPE NCC
  
   All Rights Reserved
   
@@ -54,6 +54,10 @@
 #define TEMPORARY ""
 #endif
 
+/* logging contexts */
+static LG_context_t *qi_context;
+static LG_context_t *sql_context;
+
 /*++++++++++++++++++++++++++++++++++++++
   Function invoked on query cancellation by the watchdog,
   used from the sql_execute_watched() function.
@@ -73,8 +77,8 @@ static
 void *qi_kill_body(void *arg)
 {
   SQ_connection_t *sql_connection = arg;
-  ER_dbg_va(FAC_QI, ASP_QI_WATCH,
-	      "rtc: killing SQL connection %d", (sql_connection)->thread_id);
+  LG_log(qi_context, LG_DEBUG,
+	 "rtc: killing SQL connection %d", (sql_connection)->thread_id);
   /* abort the running query */
   SQ_abort_query(sql_connection);
 
@@ -165,12 +169,12 @@ int sql_execute_watched(sk_conn_st *condat, SQ_connection_t **sql_connection,
     
       tempcon = SQ_duplicate_connection(*sql_connection);
     
-      ER_dbg_va(FAC_QI, ASP_QI_WATCH,
+      LG_log(qi_context, LG_DEBUG,
 		"rtc: closing SQL thread %d", (*sql_connection)->thread_id);
       SQ_close_connection(*sql_connection);
     
       *sql_connection = tempcon;
-      ER_dbg_va(FAC_QI, ASP_QI_WATCH,
+      LG_log(qi_context, LG_DEBUG,
 		"rtc: reopened as thread %d", (*sql_connection)->thread_id);
     
       /* make it look as if there was no error and 
@@ -254,7 +258,7 @@ static void create_name_query(GString *query_str, const char *sql_query, const c
 static int create_asblock_query(GString *query_str, 
 				const char *sql_query, 
 				const char *keys) {
-  char *keycopy = wr_string(keys);
+  char *keycopy = UT_strdup(keys);
   char *token, *cursor = keycopy;
   int  asnums[2] = {0,0};
   int index = 0; /* index into the asnums array */
@@ -396,12 +400,14 @@ static char *create_query(const Query_t q, const Query_command *qc)
       ip_range_t myrang;
       unsigned   begin, end;
       ip_keytype_t key_type;
+      int  err;
       
       /* The only inverse query for IPADDRESS is nserver. */
       /* We need to insure that we don't try to use the numeric values for this
        * query, because the address of the server is stored as a string, and
        * the SQL query is formatted appropriately. */
-      if (NOERR(IP_smart_range(qc->keys, &myrang, IP_EXPN, &key_type))) {
+      if (NOERR(err = IP_smart_range(qc->keys, &myrang, IP_EXPN, &key_type))) 
+      {
         if(IP_rang_b2_space(&myrang) == IP_V4 ) {
 	  IP_rang_b2v4(&myrang, &begin, &end);
 	  if (querytype == Q_INVERSE) {
@@ -505,7 +511,7 @@ char *QI_fast_output(const char *str)
       /* if there's no colon for whatever reason, dump the object
 	 and report the condition */
       if( colon == NULL ) {
-	ER_perror(FAC_QI, QI_INVOBJ, " [%s]", lines[0]);
+        LG_log(qi_context, LG_ERROR, " [%s]", lines[0]);
 	goto fast_output_cleanup;
       }
       *colon = '\0';
@@ -515,7 +521,7 @@ char *QI_fast_output(const char *str)
 
       if( (i = DF_attribute_name2type(attr)) == -1 ) {
 	  /* warning! error in the object format */
-	ER_perror(FAC_QI, QI_INVOBJ, " [%s]", lines[0]);
+        LG_log(qi_context, LG_ERROR, " [%s]", lines[0]);
 	goto fast_output_cleanup;
 		
       }
@@ -661,8 +667,8 @@ static int write_results(SQ_result_set_t *result,
       type = atoi(objt);
 	
       /* ASP_QI_LAST_DET */
-      ER_dbg_va(FAC_QI, ASP_QI_LAST_DET,
-	        "Retrieved serial id = %d , type = %s", atoi(str), objt);
+      LG_log(qi_context, LG_DEBUG, 
+	     "Retrieved serial id = %d , type = %s", atoi(str), objt);
 	
       UT_free(str);
       UT_free(objt);
@@ -745,7 +751,7 @@ __report_sql_error(sk_conn_st *condat,
     SK_cd_puts(condat, sql_error_text);
 
     /* next, log this error */
-    ER_perror(FAC_QI, QI_SQLERR, "at %s:%d, tid:%lu [%d] %s sql='%s'", 
+    LG_log(sql_context, LG_ERROR, "at %s:%d, tid:%lu [%d] %s sql='%s'", 
 		      file, line, (unsigned long)tid,
 		      SQ_errno(sql_connection), 
 		      SQ_error(sql_connection),
@@ -843,7 +849,7 @@ rx_node_has_mnt_irt (sk_conn_st *condat,
         num_irt_ref = 0;
     } else {
         if (SQ_get_column_int(result_ptr, row, 0, &num_irt_ref) != 0) {
-            ER_perror(FAC_QI, QI_SQLERR, "bad column at %s:%d", 
+            LG_log(sql_context, LG_ERROR, "bad column at %s:%d", 
                       __FILE__, __LINE__);
             num_irt_ref = 0;
         }
@@ -915,7 +921,6 @@ mnt_irt_filter (sk_conn_st *condat,
     for (p=*datlist; p != NULL; p = g_list_next(p)) {
         rx_data = (rx_datcpy_t *)p->data;
         UT_free(rx_data->leafcpy.data_ptr);
-        p = g_list_next(p);
     }
     wr_clear_list(datlist);
 
@@ -1059,7 +1064,7 @@ static int map_qc2rx(Query_instruction *qi, const Query_command *qc) {
   if( allflags > 1 ) {
       /* user error  (this should have been checked before) */
       
-      ER_dbg_va(FAC_QI, ASP_QI_SKIP, 
+      LG_log(qi_context, LG_INFO,
 		"ERROR in qc2rx mapping: bad combination of flags");
       result = 0;
   }
@@ -1093,10 +1098,6 @@ static int map_qc2rx(Query_instruction *qi, const Query_command *qc) {
       qi->rx_par_a = 0;
   }
   
-  if( qi->rx_srch_mode == RX_SRCH_MORE && (qc->S == 1) ) {
-      qi->rx_srch_mode = RX_SRCH_DBLS;
-  }
-  
   return result;
   
 } /* map_qc2rx() */
@@ -1128,58 +1129,58 @@ void run_referral(Query_environ *qe,
 		  unsigned ref_port_int,
 		  char *qry)
 {
-  
-#if 1 /* switch off for testing */
-  er_ret_t err;
+  int err;
+  int sk_err;
   char *rep;
 
-        /* WH_sock(sock, host, port, query, maxlines, timeout)) */
+  /* WH_sock(sock, host, port, query, maxlines, timeout)) */
   err= WH_cd_sock(&(qe->condat), ref_host, ref_port_int, qry, 
-		  ca_get_referralmaxlines, ca_get_referraltimeout
+		  ca_get_referralmaxlines, ca_get_referraltimeout, &sk_err
 		  );
 
-  switch( err ) {
-  case SK_OK:
-    /* OK */
-    break;
-  case SK_TIMEOUT:
-    /* Referral timeout */
-    rep = ca_get_qi_ref_tmout ;
-    SK_cd_puts(&(qe->condat), rep);
-    UT_free(rep);
-    break;
-	    
-  case SK_BADHOST:
-    /* Referral host not found */
-    rep = ca_get_qi_ref_badhost ;
-    SK_cd_puts(&(qe->condat), rep);
-    UT_free(rep);
-    break;
+  if (err != WH_OK) {
+    if (err == WH_MAXLINES) {
+      /* Referral reply line limit exceeded */
+      rep = ca_get_qi_ref_overmaxlin ;
+      SK_cd_puts(&(qe->condat), rep);
+      UT_free(rep);
+    } else if (err == WH_SK_ERR) {
+      switch (sk_err) {
+        case SK_TIMEOUT:
+          /* Referral timeout */
+          rep = ca_get_qi_ref_tmout ;
+          SK_cd_puts(&(qe->condat), rep);
+          UT_free(rep);
+          break;
+	          
+        case SK_BADHOST:
+          /* Referral host not found */
+          rep = ca_get_qi_ref_badhost ;
+          SK_cd_puts(&(qe->condat), rep);
+          UT_free(rep);
+          break;
+      
+        case SK_CONNECT:
+          /* Referral host not responding */
+          rep = ca_get_qi_ref_hostnottresp ;
+          SK_cd_puts(&(qe->condat), rep);
+          UT_free(rep);
+          break;
 
-  case SK_CONNECT:
-    /* Referral host not responding */
-    rep = ca_get_qi_ref_hostnottresp ;
-    SK_cd_puts(&(qe->condat), rep);
-    UT_free(rep);
-    break;
+        case SK_BIND:
+        case SK_SOCKET:
+          /* XXX internal server problem...  */
+          die; 
 
-  case SK_BIND:
-  case SK_SOCKET:
-    /* XXX internal server problem...  */
-    die; 
-
-  case WH_MAXLINES:
-    /* Referral reply line limit exceeded */
-    rep = ca_get_qi_ref_overmaxlin ;
-    SK_cd_puts(&(qe->condat), rep);
-    UT_free(rep);
-    break;
-    
-  default: /* any other errors ? */
-    die;
-    ;
-  } /*switch WH_sock */
-#endif
+        default:
+          /* XXX unexpected socket error...  */
+          die;
+      }
+    } else {
+      /* XXX unexpected WH error...  */
+      die;
+    }
+  } 
   
 }/*run_referral*/
 
@@ -1272,7 +1273,7 @@ void qi_prep_run_refer(char *domain,
     }
 	    
     /* do the referral */
-    ER_dbg_va(FAC_QI, ASP_QI_REF_GEN, "referral host is %s", ref_host); 
+    LG_log(qi_context, LG_DEBUG, "referral host is %s", ref_host); 
       
     run_referral( qe, ref_host, ref_port, querystr->str);
       
@@ -1345,7 +1346,7 @@ qi_collect_domain(char *sourcename,
     SQ_row_t *row;
     SQ_result_set_t *result_referrals = NULL;
 
-    ER_dbg_va(FAC_QI, ASP_QI_REF_DET, "run_referral: checking %s", dot);
+    LG_log(qi_context, LG_DEBUG, "run_referral: checking %s", dot);
 
     /* domain lookup -- query into the _S table */
     g_string_sprintf(sql_command, 
@@ -1548,7 +1549,7 @@ qi_collect_ids(ca_dbSource_t *dbhdl,
   int i;
   int  count, errors=0;
   GString *sql_command;
-  er_ret_t err;
+  int err;
   char sub_table[64];
   int limit ;
              /* a limit on the max number of objects to be returned
@@ -1640,7 +1641,7 @@ qi_collect_ids(ca_dbSource_t *dbhdl,
 	} /* not DN */
       } /* if SQL query not NULL */
       
-      ER_dbg_va(FAC_QI, ASP_QI_COLL_DET,
+      LG_log(qi_context, LG_DEBUG,
 		"%d entries added in %s query for %s",
 		count, Query[qi->queryindex].descr, qis->qc->keys
 		);
@@ -1656,20 +1657,16 @@ qi_collect_ids(ca_dbSource_t *dbhdl,
      
 
       if( NOERR(err)) {
-	if( ER_is_traced(FAC_QI, ASP_QI_COLL_DET ) ) {
-	  /* prevent unnecessary g_list_length call */
-	  
-	  ER_dbg_va(FAC_QI, ASP_QI_COLL_DET,
+        LG_log(qi_context, LG_DEBUG, 
 		    "%d entries after %s (mode %d par %d reg %d) query for %s",
 		    g_list_length(*datlist),
 		    Query[qi->queryindex].descr,
 		    qi->rx_srch_mode, qi->rx_par_a, 
 		    dbhdl,
 		    qi->rx_keys);
-	}
       }
       else {
-	ER_inf_va(FAC_QI, ASP_QI_COLL_DET,
+        LG_log(qi_context, LG_INFO,
 		  "RP_asc_search returned %x ", err);
       }
       break;
@@ -1902,7 +1899,7 @@ qi_fetch_references(SQ_connection_t **sql_connection,
 	marek - the rest.
   +html+ </PRE>
 ++++++++++++++++++++++++++++++++++++++*/
-er_ret_t QI_execute(ca_dbSource_t *dbhdl,
+int QI_execute(ca_dbSource_t *dbhdl,
 		    Query_instructions *qis, 
 		    Query_environ *qe,	
 		    acc_st *acc_credit,
@@ -1931,7 +1928,7 @@ er_ret_t QI_execute(ca_dbSource_t *dbhdl,
 
   /* return error if occurred */
   if (sql_connection == NULL) {
-    ER_perror(FAC_QI, QI_CANTDB," database='%s' [%d] %s", 
+    LG_log(qi_context, LG_ERROR, " database='%s' [%d] %s", 
 	      dbname, SQ_errno(sql_connection), SQ_error(sql_connection));
     UT_free(dbname);
     return QI_CANTDB;
@@ -2152,6 +2149,7 @@ static int valid_query(const Query_command *qc, const Query_t q) {
 Query_instructions *QI_new(const Query_command *qc, const Query_environ *qe) {
   Query_instructions *qis=NULL;
   Query_instruction *qi=NULL;
+  Query_instruction tmp_qi;
   int i_no=0;
   int i;
   char *query_str;
@@ -2163,23 +2161,23 @@ Query_instructions *QI_new(const Query_command *qc, const Query_environ *qe) {
   qis->recursive = qc->recursive;
   qis->qc = (qc);
 
-  
   for (i=0; Query[i].query != NULL; i++) {
 
     /* If a valid query. */
     if ( valid_query(qc, Query[i]) == 1) {
 
-      qi = (Query_instruction *)UT_calloc(1, sizeof(Query_instruction));
-
-      qi->queryindex = i;
+      memset(&tmp_qi, 0, sizeof(Query_instruction));
+      tmp_qi.queryindex = i;
 
       /* SQL Query */
       if ( Query[i].refer == R_SQL) {
-        qi->search_type = R_SQL;
+        tmp_qi.search_type = R_SQL;
         query_str = create_query(Query[i], qc);
 
         if (query_str!= NULL) {
-          qi->query_str = query_str;
+          tmp_qi.query_str = query_str;
+          qi = (Query_instruction *)UT_calloc(1, sizeof(Query_instruction));
+          *qi = tmp_qi;
           qis->instruction[i_no++] = qi;
         }
       }
@@ -2191,9 +2189,9 @@ Query_instructions *QI_new(const Query_command *qc, const Query_environ *qe) {
             continue;
         }
 
-        qi->search_type = R_RADIX;
+        tmp_qi.search_type = R_RADIX;
 	
-        if (map_qc2rx(qi, qc) == 1) {
+        if (map_qc2rx(&tmp_qi, qc) == 1) {
 	  int j;
 	  int found=0;
 	  
@@ -2204,19 +2202,17 @@ Query_instructions *QI_new(const Query_command *qc, const Query_environ *qe) {
 	    
 	    if(    qij->search_type == R_RADIX
 		   && Query[qij->queryindex].attribute 
-		   == Query[qi ->queryindex].attribute) {
+		   == Query[tmp_qi.queryindex].attribute) {
 	      
               found=1;
               break;
             }
           }
 	  
-          if ( found ) {
-            /* Discard the Query Instruction */
-            UT_free(qi);
-          } 
-          else {
+          if (!found) {
             /* Add the query_instruction to the array */
+            qi = (Query_instruction *)UT_calloc(1, sizeof(Query_instruction));
+            *qi = tmp_qi;
             qis->instruction[i_no++] = qi;
           }
         }
@@ -2233,7 +2229,7 @@ Query_instructions *QI_new(const Query_command *qc, const Query_environ *qe) {
   {  /* tracing */
       char *descrstr = QI_queries_to_string(qis);
 
-      ER_dbg_va(FAC_QI, ASP_QI_COLL_GEN, "Queries: %s", descrstr );
+      LG_log(qi_context, LG_DEBUG, "Queries: %s", descrstr );
       UT_free( descrstr );
   }
 
@@ -2284,3 +2280,13 @@ char *QI_queries_to_string(Query_instructions *qis)
    
    return resstr;
 }
+
+
+void
+QI_init (LG_context_t *qi_ctx, LG_context_t *sql_ctx)
+{
+  qi_context = qi_ctx;
+  sql_context = sql_ctx;
+}
+
+
