@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.8 $
+  $Revision: 1.12 $
 
   Radix tree (rx).  rx_global.h - header file with definition of 
                                   global vars for radix
@@ -40,7 +40,7 @@
 #include <defs.h>
 
 #include <iproutines.h>
-#include <erroutines.h>
+/*#include <erroutines.h>*/
 #include <rxroutines.h>
 #include <mysql_driver.h>
 
@@ -48,6 +48,11 @@
 #include "ca_defs.h"
 #include <thread.h>
 
+/* error codes */
+#define RP_OK      0
+#define RP_NOTREE  1
+#define RP_NOYETI  2
+#define RP_BADKEY  3
 
 typedef struct {
   rx_fam_t   fam;
@@ -93,15 +98,15 @@ typedef struct {
   rx_tree_t       *tree;        /*+ tree +*/
 } rp_tentry_t;
 
-er_ret_t RP_asc_load(char *filename, int maxobj, 
+int RP_asc_load(char *filename, int maxobj, 
 		     int operation, rp_regid_t reg_id);
-er_ret_t 
+int 
 RP_tree_get ( rx_tree_t **treeptr, /*+ answer goes here, please +*/
 	      rp_regid_t reg_id,   /*+ id of the registry +*/
 	      ip_space_t spc_id,   /*+ type of space (ipv4/ipv6) +*/
 	      rp_attr_t  attr    /*+ extra tree id (within the same reg/spc/fam +*/
 	      );
-er_ret_t 
+int 
 RP_tree_add (
 	     rp_regid_t reg_id,    /*+ id of the registry +*/
 	     rp_attr_t  attr,      /*+ extra tree id (within the same registry/space/family +*/
@@ -110,14 +115,14 @@ RP_tree_add (
 	     rx_subtree_mt subtrees	/*+ one of NONE, AUTO, HAND +*/
 	     );
 
-er_ret_t 
+int 
 RP_tree_del (rx_tree_t *treeptr); /* pointer to a tree structrute */
 
-er_ret_t 
+int 
 RP_init_trees( rp_regid_t reg_id );
 
 
-er_ret_t
+int
 RP_asc_search ( 
                rx_srch_mt search_mode, 
                int par_a,
@@ -128,7 +133,7 @@ RP_asc_search (
                GList **anslist,    /*+ answers go here, please +*/
                int    max_count    /*+ max # of answers. RX_ALLANS == unlimited +*/
                );
-er_ret_t
+int
 RP_uni_node ( rx_oper_mt mode,       /*+ MODE={cre|mod|del} +*/
 	      rp_uni_t   *uni,       /*+ unified argument structure +*/
 	      rp_attr_t  attr,       /*+ additional tree attribute +*/
@@ -137,7 +142,7 @@ RP_uni_node ( rx_oper_mt mode,       /*+ MODE={cre|mod|del} +*/
 	      unsigned datalen,      /*+ length of the payload +*/
 	      sql_key_t key          /*+ the key to the SQL full-text +*/
 	      );
-er_ret_t
+int
 RP_asc_node( rx_oper_mt mode,       /*+ MODE={cre|mod|del} +*/
 	       char *rangstr,         /*+ string prefix/range/IP/inaddr +*/
 	       rp_attr_t  attr,       /*+ additional tree attribute +*/
@@ -149,42 +154,42 @@ RP_asc_node( rx_oper_mt mode,       /*+ MODE={cre|mod|del} +*/
 
 rx_fam_t RP_attr2fam( rp_attr_t type );
 int RP_attr2spc(rp_attr_t type, ip_space_t space);
-er_ret_t
-RP_asc2uni(char       *astr,       /*+ string prefix/range/IP/inaddr +*/
+int
+RP_asc2uni(const char *astr,       /*+ string prefix/range/IP/inaddr +*/
 	   rp_attr_t  attr,
 	   rp_uni_t   *uni);        /* destination pointer */
-er_ret_t
-RP_asc2pack(rp_upd_pack_t *pack, rp_attr_t type, char *string);
+int
+RP_asc2pack(rp_upd_pack_t *pack, rp_attr_t type, const char *string);
 
 
-void RP_pack_set_orig( rp_attr_t  attr,rp_upd_pack_t *pack, char *origin);
-void RP_pack_set_pref4(rp_attr_t  attr,char *avalue, rp_upd_pack_t *pack,
+int RP_pack_set_orig( rp_attr_t  attr,rp_upd_pack_t *pack, const char *origin);
+int RP_pack_set_pref4(rp_attr_t  attr,const char *avalue, rp_upd_pack_t *pack,
 		       unsigned *prefix, unsigned *prefix_length);
-void RP_pack_set_revd( rp_attr_t  attr,char *avalue, rp_upd_pack_t *pack);
-void RP_pack_set_pref6(rp_attr_t  attr,char *avalue, rp_upd_pack_t *pack,
+int RP_pack_set_revd( rp_attr_t  attr,const char *avalue, rp_upd_pack_t *pack);
+int RP_pack_set_pref6(rp_attr_t  attr,const char *avalue, rp_upd_pack_t *pack,
 		       ip_v6word_t *high, ip_v6word_t *low, unsigned *prefix_length);
-void RP_pack_set_rang( rp_attr_t  attr,char *avalue, rp_upd_pack_t *pack,
+int RP_pack_set_rang( rp_attr_t  attr,const char *avalue, rp_upd_pack_t *pack,
 		      unsigned *begin_in, unsigned *end_in);
 
-er_ret_t
+int
 RP_pack_update(rx_oper_mt   mode, 
 	       rp_upd_pack_t *pack,
 	       rp_regid_t    reg_id);     /*+ id of the registry +*/
 
 
-er_ret_t
+int
 RP_pack_node(rx_oper_mt   mode, 
 	     rp_upd_pack_t *pack, 
 	     rp_regid_t    reg_id);
-er_ret_t
+int
 RP_pack_node_l(rx_oper_mt    mode, 
 	       rp_upd_pack_t *pack, 
 	       rx_tree_t     *mytree);
 
 void rp_make_short(rp_upd_pack_t *pack, char **ptr, unsigned *len);
 
-er_ret_t RP_sql_load_reg(rp_regid_t reg_id);
-er_ret_t RP_asc_load(char *filename, int maxobj, int operation, 
+int RP_sql_load_reg(rp_regid_t reg_id);
+int RP_asc_load(char *filename, int maxobj, int operation, 
 	    rp_regid_t reg_id);
 int RP_attr2spc(rp_attr_t type, ip_space_t space);
 #undef EXTDEF
