@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.24 $
+  $Revision: 1.30 $
 
   Radix payload (rp) - user level functions for storing data in radix trees
 
@@ -29,22 +29,19 @@
   AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ***************************************/
-#include <rp.h>
-#include <mysql_driver.h>
-#include <constants.h>
-#include "ca_configFns.h"
-#include "ca_dictionary.h"
-#include "ca_macros.h"
-#include "ca_srcAttribs.h"
-#include "ta.h"
+
+#include "rip.h"
+
+/* logging */
+extern LG_context_t *rp_context;
 
 static
-er_ret_t
+int
 make_sql2pack(SQ_result_set_t *result, SQ_row_t *row, 
 	      rp_upd_pack_t *pack, rp_attr_t  attr, ip_space_t space, 
 	      int colcount)
 {
-  er_ret_t   conv = RP_OK;
+  int   conv = RP_OK;
   rp_uni_t   *uniptr = &(pack->uni);
   char       *idptr; /* initially set to the 0'th column */
   char       *col[5];
@@ -84,10 +81,7 @@ make_sql2pack(SQ_result_set_t *result, SQ_row_t *row,
     */
     uniptr->space = IP_V4;
     if( NOERR(conv = IP_pref_f2b_v4( &(uniptr->u.rt), col[1], col[2] ))) {
-      dieif(wr_malloc( (void **) &(pack->d.origin), strlen(col[3])+1)
-	    != UT_OK);
-
-      strcpy(pack->d.origin, col[3]);
+      pack->d.origin = UT_strdup(col[3]);
     }
     break;
   case A_DN:
@@ -101,9 +95,7 @@ make_sql2pack(SQ_result_set_t *result, SQ_row_t *row,
     */
       conv = IP_pref_f2b_v4( &(uniptr->u.rt), col[1], col[2] );
       uniptr->space = IP_pref_b2_space( &(uniptr->u.rt) );
-      dieif(wr_malloc( (void **) &(pack->d.domain), strlen(col[3])+1)
-	    != UT_OK);
-      strcpy(pack->d.domain, col[3]);
+      pack->d.domain = UT_strdup(col[3]);
     }
     else {
       /* read 0-4 from ip6int
@@ -116,9 +108,7 @@ make_sql2pack(SQ_result_set_t *result, SQ_row_t *row,
       conv = IP_pref_f2b_v6( &(uniptr->u.rt), col[1], col[2], col[3] );
       uniptr->space = IP_pref_b2_space( &(uniptr->u.rt) );
     
-      dieif(wr_malloc( (void **) &(pack->d.domain), strlen(col[4])+1)
-	    != UT_OK);
-      strcpy(pack->d.domain, col[4]);
+      pack->d.domain = UT_strdup(col[4]);
     }
     break;
   case A_I6: 
@@ -150,7 +140,7 @@ make_sql2pack(SQ_result_set_t *result, SQ_row_t *row,
 }
 
 static
-er_ret_t
+int
 RP_sql_load_attr_space( rp_attr_t attr, ip_space_t space, 
 			rp_regid_t reg_id, SQ_connection_t *con
 			)
@@ -161,12 +151,12 @@ RP_sql_load_attr_space( rp_attr_t attr, ip_space_t space,
   rx_tree_t   *mytree;
   rp_upd_pack_t pack;
   int colcount;
-  int sizedebug = ER_is_traced(FAC_RP, ASP_RP_LOAD_DET);
   char *v4 = DF_attrcode_radix_load_v4(attr);
   char *v6 = DF_attrcode_radix_load_v6(attr);
   char *vu = (space == IP_V4) ? v4 : v6;
   char *srcnam = ca_get_srcname(reg_id);
-  char activity[64];
+  const char *attr_code;
+  char *activity;
 
   dieif( vu == NULL /* loading query undefined */ );
 #if 0
@@ -177,10 +167,12 @@ RP_sql_load_attr_space( rp_attr_t attr, ip_space_t space,
 
   dieif( RP_tree_get ( &mytree, reg_id, space, attr ) != RP_OK );
  
-  ER_inf_va(FAC_RP, ASP_RP_LOAD_DET, "loading using %s", vu);
-  ER_dbg_va(FAC_RP, ASP_RP_LOAD_DET, "size before query = %x", sbrk(0));
+  LG_log(rp_context, LG_INFO, "loading using %s", vu);
+  LG_log(rp_context, LG_DEBUG, "size before query = %x", sbrk(0));
   
-  sprintf(activity, "%s/%s, query ", srcnam, DF_get_attribute_code(attr));
+  attr_code = DF_get_attribute_code(attr);
+  activity = UT_malloc(strlen(srcnam) + strlen(attr_code) + 32);
+  sprintf(activity, "%s/%s, query ", srcnam, attr_code);
   TA_setactivity(activity);
   TA_increment();
 
@@ -191,7 +183,7 @@ RP_sql_load_attr_space( rp_attr_t attr, ip_space_t space,
   else { 
     colcount = SQ_get_column_count(result);
     
-    ER_dbg_va(FAC_RP, ASP_RP_LOAD_DET, 
+    LG_log(rp_context, LG_DEBUG,
 	      "size after query = %x; columns = %d", sbrk(0), colcount);
     
     /* LOCKED when created, so no need to acquire lock here */
@@ -209,21 +201,19 @@ RP_sql_load_attr_space( rp_attr_t attr, ip_space_t space,
       
       /* free allocated memory */
       if( pack.d.origin != NULL ) {
-	wr_free(pack.d.origin);
+	UT_free(pack.d.origin);
 	pack.d.origin = NULL;
       }
       
       objnr++;
       
-      if( sizedebug ) {
-	ER_dbg_va(FAC_RP, ASP_RP_LOAD_DET, "size after object %d = %x", 
+      LG_log(rp_context, LG_DEBUG, "size after object %d = %x", 
 		  objnr, sbrk(0));
-      }
       
       if( objnr % 1000 == 0 ) {
 
 	  sprintf(activity, "%s/%s, %d done ", 
-		  srcnam, DF_get_attribute_code(attr), objnr);
+		  srcnam, attr_code, objnr);
 	  TA_setactivity(activity);
       }
     }
@@ -237,18 +227,19 @@ RP_sql_load_attr_space( rp_attr_t attr, ip_space_t space,
       die;
   }
 
-  ER_inf_va(FAC_RP, ASP_RP_LOAD_GEN, "loaded %d objects into %s", objnr,
+  LG_log(rp_context, LG_INFO, "loaded %d objects into %s", objnr,
 	    DF_get_attribute_code(attr) );
  
-  wr_free(srcnam);
+  UT_free(activity);
+  UT_free(srcnam);
   return RP_OK;
 }
 
-er_ret_t
+int
 RP_sql_load_reg(rp_regid_t reg_id) 
 {
   
-  er_ret_t err;
+  int err;
   SQ_connection_t *con;
   char *dbhost = ca_get_srcdbmachine(reg_id);
   char *dbname = ca_get_srcdbname(reg_id);
@@ -273,15 +264,19 @@ RP_sql_load_reg(rp_regid_t reg_id)
     if( !NOERR(err=RP_sql_load_attr_space( A_IN, IP_V4, reg_id, con))) {
       break;
     }
+#ifndef NO_A_I6
     if( !NOERR(err=RP_sql_load_attr_space( A_I6, IP_V6, reg_id, con))) {
       break;
     }
+#endif
+#ifndef NO_A_DN
     if( !NOERR(err=RP_sql_load_attr_space( A_DN, IP_V4, reg_id, con))) {
       break;
     }
     if( !NOERR(err=RP_sql_load_attr_space( A_DN, IP_V6, reg_id, con))) {
       break;
     }
+#endif
     /* CONSTCOND */
   } while(0);
 
@@ -293,11 +288,11 @@ RP_sql_load_reg(rp_regid_t reg_id)
   TA_delete();
 
   /* free junk */
-  wr_free(dbhost);
-  wr_free(dbname);
-  wr_free(dbuser);
-  wr_free(dbpass);
-  wr_free(srcnam);
+  UT_free(dbhost);
+  UT_free(dbname);
+  UT_free(dbuser);
+  UT_free(dbpass);
+  UT_free(srcnam);
   return err;
 }
 
@@ -306,11 +301,11 @@ RP_sql_load_reg(rp_regid_t reg_id)
    load the tree from an ascii file (short attr names).
    mainly for testing... 
 */
-er_ret_t
+int
 RP_asc_load(char *filename, int maxobj, int operation, 
 	    rp_regid_t reg_id)
 {
-  er_ret_t err;
+  int err;
   FILE *fp;
   char buf[1024];
   char fulltext[65536];
