@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.16 $
+  $Revision: 1.20 $
 
   Radix payload (rp) - user level functions for storing data in radix trees
 
@@ -12,7 +12,7 @@
   Design and implementation by: Marek Bukowy
   
   ******************/ /******************
-  Copyright (c) 1999,2000,2001                    RIPE NCC
+  Copyright (c) 1999                              RIPE NCC
  
   All Rights Reserved
   
@@ -34,6 +34,9 @@
 
 #include "rip.h"
 
+/* logging */
+extern LG_context_t *rp_context;
+
 static
 void
 rp_exclude_datlink(GList    **datlist, GList    *element)
@@ -53,7 +56,7 @@ rp_exclude_datlink(GList    **datlist, GList    *element)
    on each of them; attaches the results to datlist.
 +++++++++++*/
 static
-er_ret_t
+int
 rp_preflist_search (
                     rx_srch_mt search_mode, 
                     int par_a,
@@ -67,7 +70,7 @@ rp_preflist_search (
   char   prefstr[IP_PREFSTR_MAX];
   GList   *qitem;
   ip_prefix_t *querypref;
-  er_ret_t err;
+  int err;
   
   for( qitem = g_list_first(*preflist);
        qitem != NULL;
@@ -78,7 +81,7 @@ rp_preflist_search (
     if( IP_pref_b2a( querypref, prefstr, IP_PREFSTR_MAX) != IP_OK ) {
       die;
     }
-    ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+    LG_log(rp_context, LG_DEBUG,
               "rx_preflist_search: mode %d (%s) (par %d) for %s", 
               search_mode, RX_text_srch_mode(search_mode), par_a, prefstr);
     
@@ -120,7 +123,7 @@ rp_find_smallest_span( GList *datlist ) {
         min_span = span;
       }
     }
-    ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+    LG_log(rp_context, LG_DEBUG,
               "rp_find_smallest_span: minimal span is %d", min_span);
 
     return min_span;
@@ -166,7 +169,7 @@ rp_exclude_exact_match( GList **datlist, ip_range_t *testrang)
     if( memcmp( & refptr->leafptr->iprange, 
 		testrang, sizeof(ip_range_t)) == 0 ) {  
       rp_exclude_datlink(datlist, ditem);
-      ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+      LG_log(rp_context, LG_DEBUG,
 		"process_datlist: discarded an exact match");
     }
     ditem = newitem;
@@ -218,7 +221,7 @@ rp_find_longest_prefix(GList **datlist)
      taking span into account 
 +*/
 static
-er_ret_t
+int
 rp_asc_process_datlist(
 		       rx_srch_mt search_mode,
 		       int        par_a,
@@ -286,7 +289,7 @@ rp_asc_process_datlist(
 	 the smallest span must be returned */
       if( !exclude && use_span 
 	  && (span = IP_rang_span( &refptr->leafptr->iprange))!=min_span) {
-	ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+        LG_log(rp_context, LG_DEBUG,
 		  "process_datlist: (EX)LESS: discarded object with span %d", span);
 	exclude = 1;
       }
@@ -294,7 +297,7 @@ rp_asc_process_datlist(
        */
       if( !exclude && max_pref >= 0
 	  && refptr->leafptr->preflen < max_pref ) {
-	ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+        LG_log(rp_context, LG_DEBUG,
 		  "process_datlist: (EX)LESS: discarded object with preflen %d", 
 		  refptr->leafptr->preflen);
 	exclude = 1;
@@ -306,12 +309,12 @@ rp_asc_process_datlist(
 	  && prefnumber > 1 ) { /* do not check if all will be approved */
 	
 	if( rp_leaf_occ_inc(lohash, refptr->leafptr) < prefnumber ) {
-	  ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+          LG_log(rp_context, LG_DEBUG,
 		    "process_datlist: (EX)LESS: leafptr %x not enough",refptr->leafptr);
 	  exclude = 1;
 	} 
 	else {
-	  ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+          LG_log(rp_context, LG_DEBUG,
 		    "process_datlist: (EX)LESS: leafptr %x GOOD enough",refptr->leafptr);
 	}
       }
@@ -321,7 +324,7 @@ rp_asc_process_datlist(
       if( memcmp( & refptr->leafptr->iprange, 
 		  testrang, sizeof(ip_range_t)) != 0) {
 	
-	ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+        LG_log(rp_context, LG_DEBUG,
 		  "process_datlist: EXACT; discarded a mismatch");
 	exclude = 1;
       } /*  EXACT match */
@@ -330,7 +333,7 @@ rp_asc_process_datlist(
       /* MORE: exclude if not fully contained in the search term */
       if( ! (IP_addr_in_rang(&refptr->leafptr->iprange.begin, testrang )
 	  && IP_addr_in_rang(&refptr->leafptr->iprange.end, testrang ))) {
-	ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+        LG_log(rp_context, LG_DEBUG,
 		  "process_datlist: MORE; discarded a not-fully contained one");
 	exclude = 1;
       }
@@ -360,7 +363,7 @@ rp_asc_process_datlist(
 
 /*+ appends the element pointed to by datref to finallist +*/
 static
-er_ret_t
+int
 rp_asc_append_datref(rx_datref_t *refptr, GList **finallist)
 {
   rx_datcpy_t *datcpy;
@@ -382,7 +385,7 @@ rp_asc_append_datref(rx_datref_t *refptr, GList **finallist)
     *finallist = g_list_prepend(*finallist, datcpy);
 
     /* XXX this wouldn't work in access_control */
-    ER_dbg_va(FAC_RP, ASP_RP_SRCH_DATA,
+    LG_log(rp_context, LG_DEBUG,
 	      "rp_asc_append 'ed: %s", dataptr);
 
     return RX_OK;
@@ -399,17 +402,17 @@ returns: error from wr_malloc
 
 +*/
 static
-er_ret_t
+int
 rp_srch_copyresults(GList *datlist,
 		    GList **finallist,
 		    int maxcount)
 {
-  er_ret_t err;
+  int err;
   GList    *ditem;
   GHashTable *uniqhash = g_hash_table_new(NULL, NULL); /* defaults */
   int count = 0;
 
-  ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET, "srch_copyresults");
+  LG_log(rp_context, LG_DEBUG, "srch_copyresults");
 
   /*  copy dataleaves pointed to by entries from the datlist
       only once (check uniqueness in the hash table) */
@@ -459,7 +462,7 @@ rp_begend_preselection(GList **datlist, rx_fam_t fam_id, ip_range_t *testrang)
     /* the test is indentical for route & inetnum trees */
     if( IP_addr_in_rang(&testrang->end, &refptr->leafptr->iprange) == 0 ) {
       
-      ER_dbg_va(FAC_RP, ASP_RP_SRCH_DET,
+      LG_log(rp_context, LG_DEBUG, 
 		"process_datlist: discarded an uncovering leafptr %x",
 		refptr->leafptr);
       rp_exclude_datlink(datlist, ditem);
@@ -501,7 +504,7 @@ rp_begend_preselection(GList **datlist, rx_fam_t fam_id, ip_range_t *testrang)
 
   returns RX_OK or a code from an underlying function
 ++++++++++++*/
-er_ret_t
+int
 RP_asc_search ( 
                rx_srch_mt search_mode, 
                int par_a,
@@ -515,7 +518,7 @@ RP_asc_search (
 { 
   GList    *preflist = NULL;
   GList    *datlist = NULL;
-  er_ret_t   err; 
+  int   err; 
   ip_range_t  testrang;
   int        locked = 0;
   ip_keytype_t key_type;
@@ -527,15 +530,15 @@ RP_asc_search (
   
 
   /*  abort on error (but unlock the tree) */  
-  ER_dbg_va(FAC_RP, ASP_RP_SRCH_GEN,
+  LG_log(rp_context, LG_DEBUG, 
 	    "RP_NEW_asc_search:  query %s : mode %d (%s) (par %d) for %s",
 	    DF_get_attribute_name(attr),
 	    search_mode, RX_text_srch_mode(search_mode), par_a, key);
 
   
   /* parse the key into a prefix list */
-  if( ( err = IP_smart_conv(key, 0, 0,
-			    &preflist, IP_EXPN, &key_type)) != IP_OK ) {
+  if(!NOERR( err = IP_smart_conv(key, 0, 0,
+			    &preflist, IP_EXPN, &key_type))) {
     /* operational trouble (UT_*) or invalid key (IP_INVARG)*/
     return err; 
   }
@@ -593,7 +596,7 @@ RP_asc_search (
     }
   } /* collection */
 
-  ER_dbg_va(FAC_RP, ASP_RP_SRCH_GEN,
+  LG_log(rp_context, LG_DEBUG, 
 	    "RP_NEW_asc_search: collected %d references ",
 	    g_list_length(datlist));
 
