@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.25 $
+  $Revision: 1.28 $
 
   Radix tree (rx). rxroutines.h - header file for radix tree handling module.
 
@@ -42,12 +42,15 @@
 #include <memwrap.h>
 #include <stdio.h>
 #include <iproutines.h>
-#include <erroutines.h>
+/*#include <erroutines.h>*/
 
 #include "sk.h" /*condat*/
 
 #include "thread.h" /*rwlock*/
 
+/* errors */
+#define RX_OK      0
+#define RX_DATNOF  1
 
 typedef enum {
   RX_FAM_RT = 1,
@@ -319,10 +322,10 @@ void rx_free_list_element(void *cpy, void *trash);
 
 
 
-er_ret_t
+int
 RX_treecheck( rx_tree_t *tree, int datatoo, rx_treecheck_t *errorfound);
 
-er_ret_t 
+int 
 RX_tree_cre (
 	      char      *prefixstr, /*+ prefix the tree will cover (string) +*/
 	      rx_fam_t   fam_id,
@@ -331,7 +334,7 @@ RX_tree_cre (
 	      rx_tree_t **treestore /* store the tree pointer here */
 	     );
 
-er_ret_t
+int
 RX_bin_search (
 	       rx_srch_mt  search_mode,
 	       int     	   par_a,
@@ -341,27 +344,27 @@ RX_bin_search (
 	       GList       **datleaves,    /* data leaves go here */
 	       int         max_count 
 	       );
-er_ret_t
+int
 rx_bin_node (
 	     rx_oper_mt   mode,       /*+ MODE={cre|mod|del} +*/
 	     ip_prefix_t *newpref,    /*+ prefix of the node +*/
 	     rx_tree_t	*tree,        /*+ pointer to the tree structure +*/
 	     rx_dataleaf_t *dataleaf  /*+ dataleaf to attach at the node +*/
 	     );
-er_ret_t
+int
 RX_rt_node (
 	     rx_oper_mt   mode,       /*+ MODE={cre|mod|del} +*/
 	     ip_prefix_t *newpref,    /*+ prefix of the node +*/
 	     rx_tree_t	*tree,        /*+ pointer to the tree structure +*/
 	     rx_dataleaf_t *dataleaf  /*+ dataleaf to attach at the node +*/
 	     );
-er_ret_t
+int
 RX_in_node(   rx_oper_mt mode,       /*+ MODE={cre|mod|del} +*/
 	      ip_range_t *rang,      /*+ range of IP addresses +*/
 	      rx_tree_t *tree,       /*+ pointer to the tree structure +*/
 	      rx_dataleaf_t *leafptr /*+ dataleaf to attach at the node +*/
 	      );
-er_ret_t
+int
 rx_build_stack(rx_nodcpy_t    stack[], 
 	       int            *maxdepth, 
 	       rx_tree_t      *tree, 
@@ -369,7 +372,7 @@ rx_build_stack(rx_nodcpy_t    stack[],
 	       rx_stk_mt      dmode
 	       );
 
-er_ret_t
+int
 rx_nod_search (
 	       rx_srch_mt  search_mode,
 	       int     	   par_a,
@@ -387,17 +390,17 @@ rx_nod_search (
 	       );
 int
 rx_walk_tree(rx_node_t *node, 
-	     er_ret_t (*func)(rx_node_t *node, int level, int nodecounter,
+	     int (*func)(rx_node_t *node, int level, int nodecounter,
 			      void *userptr), 
 	     rx_walk_mt walk_mode, 
 	     int maxlevel, 
 	     int level, 
 	     int nodecounter,
 	     void *userptr,
-	     er_ret_t *err);
+	     int *err);
 
 
-er_ret_t rx_tree_print( sk_conn_st *condat,rx_tree_t     *tree );
+int rx_tree_print( sk_conn_st *condat,rx_tree_t     *tree );
 void rx_space_list(sk_conn_st *condat);
 void rx_nod_print( rx_node_t *node, char *buf, unsigned maxchar );
 void rx_stk_print( rx_nodcpy_t   stack[], int stackdepth );
