@@ -1,14 +1,14 @@
 #ifndef READ_SOCKET
 #define READ_SOCKET
 /***************************************
-  $Revision: 1.10 $
+  $Revision: 1.14 $
 
   Socket module (sk)
 
   Status: NOT REVUED, NOT TESTED
 
   ******************/ /******************
-  Copyright (c) 1999,2000,2001,2002               RIPE NCC
+  Copyright (c) 1999                              RIPE NCC
  
   All Rights Reserved
   
@@ -53,6 +53,10 @@
 #include <stdio.h>
 
 #include "iproutines.h"
+#include "lg.h"
+
+/* maximum amount of input data to buffer */
+#define INPUT_BUF_LEN 2048
 
 /* connection data -> helps keep track of all errors etc */
 typedef struct {
@@ -68,18 +72,29 @@ typedef struct {
   pthread_mutex_t watchmutex;
 
   unsigned char  lasterr;      /* timeout, interrupt, etc. */
-  ip_addr_t rIP;              /* real IP */
-  ip_addr_t eIP;              /* effective IP */
+  ip_addr_t rIP;               /* real IP */
+  ip_addr_t eIP;               /* effective IP */
   char *ip;                    /* text of the eIP */
+
+  char rd_buf[INPUT_BUF_LEN];  /* buffer for input */
+  int rd_buf_len;              /* number of characters in input buffer */
 } sk_conn_st;
 
+/* error values */
+#define SK_OK        0
+#define SK_BADHOST   1
+#define SK_CONNECT   2
+#define SK_BIND      3
+#define SK_SOCKET    4
+
 /* reasons to close: socket-wise .... */
-#define SK_DISCONNECT 0x0001
-#define SK_INTERRUPT  0x0002
-#define SK_TIMEOUT    0x0004
+#define SK_DISCONNECT  8
+#define SK_INTERRUPT  16 
+#define SK_TIMEOUT    32
 
 /* ... and user-wise: */
-#define SK_NOTEXT     0x0100
+#define SK_NOTEXT     64
+
 
 #ifdef __cplusplus
 extern "C" {
@@ -89,18 +104,15 @@ extern "C" {
 int SK_atoport(const char *service, const char *proto);
 int SK_close(int  socket);
 int SK_getsock(int socket_type, unsigned port, int backlog, uint32_t bind_address);
-er_ret_t SK_connect(int *sock, char *hostname, unsigned port, unsigned timeout);
+int SK_connect(int *sock, char *hostname, unsigned port, unsigned timeout);
 int SK_accept_connection(int listening_socket);
-int SK_read(int  sockfd, char *buf, size_t count);
 int SK_write(int sockfd, 
              const char *buf, 
 	     int count, 
 	     const struct timeval *timeout,
 	     int *count_sent);
-int SK_gets(int  sockfd, char *str, size_t count);
 int SK_puts(int  sockfd, const char *str, const struct timeval *timeout);
 int SK_putc(int  sockfd, char ch, const struct timeval *timeout);
-int SK_getc(int  sockfd);
 char *SK_getpeername(int sockfd);
 int SK_getpeerip(int sockfd, ip_addr_t *ip);
 
@@ -114,10 +126,10 @@ int SK_cd_printf(sk_conn_st *condat, char *txt, ...)
      __attribute__ ((format (printf, 2, 3)))
 #endif
      ;
-void SK_init(void);
+void SK_init(LG_context_t *ctx);
 
-er_ret_t SK_watchstart(sk_conn_st *condat);
-er_ret_t SK_watchstop(sk_conn_st *condat);
+int SK_watchstart(sk_conn_st *condat);
+int SK_watchstop(sk_conn_st *condat);
 void SK_watch_setkill(sk_conn_st *condat, pthread_t killthis);
 void SK_watch_setexec( sk_conn_st *condat, void *(*function)(void *), void *args);
 void SK_watch_setclear(sk_conn_st *condat);
@@ -125,6 +137,12 @@ void SK_watchexec(sk_conn_st *condat);
 void SK_watchkill(sk_conn_st *condat);
 void SK_watchtrigger(sk_conn_st *condat);
 
+/* INTERNAL USE ONLY */
+int sk_fill_rd_buf(sk_conn_st *condat);
+#define sk_rd_buf_full(condat) (((condat)->rd_buf_len) >= sizeof((condat)->rd_buf))
+
+
+
 #ifdef __cplusplus
 }
 #endif
