@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.39 $
+  $Revision: 1.44 $
 
   SQL module (sq) - this is a MySQL implementation of the SQL module.
 
@@ -11,7 +11,7 @@
                         marek@ripe.net
   OSs Tested          : Solaris 7 / sun4u / sparc
   ******************/ /******************
-  Copyright (c) 1999, 2000, 2001                  RIPE NCC
+  Copyright (c) 1999                              RIPE NCC
  
   All Rights Reserved
   
@@ -43,6 +43,14 @@
 #include <errno.h>
 #include <glib.h>
 
+static LG_context_t *sq_context;
+
+void
+SQ_init (LG_context_t *ctx)
+{
+  sq_context = ctx;
+}
+
 /* 
 Description:
 
@@ -79,7 +87,7 @@ Notes:
   so the MySQL documentation should be checked for current meaning.
 */
 
-er_ret_t 
+int 
 SQ_try_connection (SQ_connection_t **conn, const char *host,
                    unsigned int port, const char *db,
                    const char *user, const char *password)
@@ -89,6 +97,8 @@ SQ_try_connection (SQ_connection_t **conn, const char *host,
     *conn = mysql_init(NULL);
     dieif(*conn == NULL);  /* XXX SK - need to call "out of memory handler" */
 
+    mysql_options(*conn, MYSQL_READ_DEFAULT_GROUP, "client");
+
     res = mysql_real_connect(*conn, host, user, password, db, port, NULL, 0);
     if (res == NULL) {
         return SQ_CTCONN;
@@ -126,7 +136,7 @@ SQ_try_connection (SQ_connection_t **conn, const char *host,
 SQ_connection_t *SQ_get_connection(const char *host, unsigned int port, const char *db, const char *user, const char *password) {
 
   SQ_connection_t *sql_connection;
-  er_ret_t res;
+  int res;
   unsigned try = 0;
 
   /* XXX MB.
@@ -153,13 +163,13 @@ SQ_connection_t *SQ_get_connection(const char *host, unsigned int port, const ch
       
       /* if we've tried enough, exit with error */
       if (try >= 3) {
-        ER_perror(FAC_SQ, SQ_CTCONN, " %s; %s", db, 
+        LG_log(sq_context, LG_SEVERE, " %s; %s", db, 
 		  sql_connection ? SQ_error(sql_connection) : "-?");
         die;
       }
 
       /* otherwise, prepare to try again */
-      ER_perror(FAC_SQ, SQ_CNCT, " %s; %s", db, 
+      LG_log(sq_context, LG_ERROR, " %s; %s", db, 
 		sql_connection ? SQ_error(sql_connection) : "-?");
 
       if (try > 0) {
@@ -206,6 +216,7 @@ int SQ_execute_query(SQ_connection_t *sql_connection,
 {
   int err;
   SQ_result_set_t *result;
+  float seconds;
 
   ut_timer_t start_time, stop_time; 
   
@@ -217,19 +228,15 @@ int SQ_execute_query(SQ_connection_t *sql_connection,
   if (err == 0) {
     result = mysql_store_result(sql_connection);
     
-    if (ER_is_traced(FAC_SQ, ASP_SQ_QRYTIME)) {
-      float seconds;
-
-      UT_timeget(&stop_time);      
-      seconds = UT_timediff( &start_time, &stop_time );
+    UT_timeget(&stop_time);      
+    seconds = UT_timediff( &start_time, &stop_time );
   
-      ER_dbg_va(FAC_SQ, ASP_SQ_QRYTIME,
+    LG_log(sq_context, LG_DEBUG,
 		"spent %.2f sec; got %d rows from [%s: %s]", 
 		seconds, 
 		SQ_get_affected_rows(sql_connection),
 		sql_connection->db, 
 		query);
-    }
     
     if(result_ptr) *result_ptr=result;
     else if(result) mysql_free_result(result);
@@ -1005,7 +1012,7 @@ SQ_abort_query(SQ_connection_t *sql_connection)
   SQ_connection_t *contemp = SQ_duplicate_connection(sql_connection);
   int res = mysql_kill(contemp, sql_connection->thread_id);
 
-  ER_dbg_va(FAC_SQ, ASP_SQ_ABORT,
+  LG_log(sq_context, LG_DEBUG,
 	    "connection %d aborted by tmp thread %d",
 	    sql_connection->thread_id,
 	    contemp->thread_id);
@@ -1070,7 +1077,7 @@ if(max==1)minmax="max"; else minmax="min";
  sql_err = SQ_execute_query(sql_connection, query->str, &sql_result);
  
  if(sql_err) {
-    ER_perror(FAC_SQ, SQ_CNCT, "%s[%s]\n", SQ_error(sql_connection), 
+    LG_log(sq_context, LG_SEVERE, "%s[%s]\n", SQ_error(sql_connection), 
               query->str);
     die;
  }
@@ -1082,7 +1089,7 @@ if(max==1)minmax="max"; else minmax="min";
      /* We must process all the rows of the result,*/
      /* otherwise we'll have them as part of the next qry */
 	while ( (sql_row = SQ_row_next(sql_result)) != NULL) {
-	  ER_perror(FAC_SQ, SQ_CNCT, "duplicate max [%s]\n", query->str);
+          LG_log(sq_context, LG_SEVERE, "duplicate max [%s]\n", query->str);
 	  die;
 	}
  }
@@ -1104,4 +1111,34 @@ if(max==1)minmax="max"; else minmax="min";
  
 }
 
+/* SQ_escape_string() */
+/*++++++++++++++++++++++++++++++++++++++
+  Returns a copy of the string passed that has been escaped so it
+  may be safely used in SQL strings.
+
+  Return values
+
+  Escaped string (allocated memory which must be freed)
+
+  More:
+  +html+ <PRE>
+  Authors:
+        shane
+  +html+ </PRE><DL COMPACT>
+  +html+ <DT>Online References:
+  +html+ <DD><UL>
+  +html+ </UL></DL>
+
+  ++++++++++++++++++++++++++++++++++++++*/
+
+char *SQ_escape_string(SQ_connection_t *sql_connection, char *str)
+{
+    char *new_str;
+    int length;
+
+    length = strlen(str);
+    new_str = (char *)UT_malloc((length * 2) + 1);
+    mysql_real_escape_string(sql_connection, new_str, str, length);
+    return new_str;
+}
 
