@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.29 $
+  $Revision: 1.31 $
 
   Example code: A thread.
 
@@ -21,7 +21,7 @@
         ottrey (17/06/1999) Stripped down.
         joao   (22/06/1999) Redid thread startup
   ******************/ /******************
-  Copyright (c) 1999,2000,2001,2002               RIPE NCC
+  Copyright (c) 1999                              RIPE NCC
  
   All Rights Reserved
   
@@ -386,17 +386,10 @@ pthread_t TH_create(void *do_function(void *), void *arguments ) {
     pthread_attr_init(&attr);     /* initialize attr with default attributes */
     pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
 
-#if defined(HAVE_PTHREAD_ATTR_GETSTACKSIZE) && \
-    defined(HAVE_PTHREAD_ATTR_SETSTACKSIZE)
+#if defined(SCO)
     /*********
       For SCO, we need to increase the stack size, because the default is
-      exceedingly small.  This also works on FreeBSD.  In Solaris, the
-      stack size is 0, which is interpreted as the default, meaning 1
-      Mbyte for 32-bit processes or 2 Mbyte for 64-bit processes.
-      However, trying to *set* the stack size to 0 results in an error.
-      Therefore, we don't want to set the size to 0.  Probably not a good
-      idea in any event.  :) Linux doesn't support this function (as of
-      the 2.4.2 kernel).
+      exceedingly small.
 
       Note: see also modules/sk/cd_watchdog.c
      *********/
