@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.12 $
+  $Revision: 1.14 $
 
   Status: NOT REVUED, NOT TESTED
 
@@ -9,7 +9,7 @@
   Modification History:
         andrei (17/01/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000,2001,2002                    RIPE NCC
+  Copyright (c) 2000                              RIPE NCC
  
   All Rights Reserved
   
@@ -122,9 +122,14 @@ typedef enum {
 #define RF_DEF_PORT	43
 
 
+/* THESE WERE IN er_UD_errors.h */
+#define UD_TAG " "
+
+#include "lg.h"
 
 void UD_do_nrtm(void *args);
 void UD_do_updates(void *args);
+void UD_init(LG_context_t *ctx);
 
 
 #endif /* _UD_H */
