@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.6 $
+  $Revision: 1.13 $
 
   Functions to keep records for crash recovery
 
@@ -11,7 +11,7 @@
   Modification History:
         andrei (11/08/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000,2001                         RIPE NCC
+  Copyright (c) 2000                              RIPE NCC
  
   All Rights Reserved
   
@@ -32,6 +32,11 @@
  ***************************************/
 
 #include "rip.h"
+#include "lg.h"
+
+/* logging (defined in ud_main.c) */
+extern LG_context_t *ud_context;
+
 
 /*************************************************************
 
@@ -81,12 +86,9 @@ SQ_result_set_t *sql_result;
 GString *query;
 int sql_err;
 
- if(tr->load_pass != 0) return(0); /* for fast loader just return */	
-	 
- if ((query = g_string_sized_new(STR_L)) == NULL){ 
-  ER_perror(FAC_UD, UD_MEM, "cannot allocate gstring\n"); 
-  die; 
- }
+ if(IS_STANDALONE(tr->mode)) return(0); /* for loader just return */
+
+ query = g_string_sized_new(STR_L);
  /* delete record if exists*/
  
  TR_delete_record(tr);
@@ -110,7 +112,7 @@ int sql_err;
  
  /* in case of an error copy error code and return */ 
  if(sql_err) {
-   ER_perror(FAC_UD, UD_SQL, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
+   LG_log(ud_context, LG_ERROR, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
    die;
  }
  g_string_free(query, TRUE);
@@ -139,12 +141,9 @@ SQ_result_set_t *sql_result;
 GString *query;
 int sql_err;
  
- if(tr->load_pass != 0) return(0); /* for fast loader just return */
+ if(IS_STANDALONE(tr->mode)) return(0); /* for loader just return */ 
  
- if ((query = g_string_sized_new(STR_L)) == NULL){ 
-  ER_perror(FAC_UD, UD_MEM, "cannot allocate gstring\n");
-  die; 
- }
+ query = g_string_sized_new(STR_L);
  
  switch(field){
    case TF_DUMMY:
@@ -197,7 +196,7 @@ int sql_err;
  
  /* in case of an error copy error code and return */ 
  if(sql_err) {
-   ER_perror(FAC_UD, UD_SQL, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
+   LG_log(ud_context, LG_ERROR, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
    die;
  }
  g_string_free(query, TRUE);
@@ -213,10 +212,7 @@ SQ_result_set_t *sql_result;
 GString *query;
 int sql_err;
  
- if ((query = g_string_sized_new(STR_L)) == NULL){ 
-  ER_perror(FAC_UD, UD_MEM, "cannot allocate gstring\n"); 
-  die; 
- }
+ query = g_string_sized_new(STR_L);
  
  /* compose query */
  if (transaction_id == TR_LAST)
@@ -230,7 +226,7 @@ int sql_err;
  
 /* in case of an error copy error code and return */ 
  if(sql_err) {
-   ER_perror(FAC_UD, UD_SQL, "%s[%s]\n", SQ_error(sql_connection), query->str);
+   LG_log(ud_context, LG_ERROR, "%s[%s]\n", SQ_error(sql_connection), query->str);
    die;
  }
  g_string_free(query, TRUE);
@@ -265,10 +261,7 @@ GString *query;
 int sql_err;
 SQ_row_t *sql_row;
 
- if ((query = g_string_sized_new(STR_L)) == NULL){ 
-  ER_perror(FAC_UD, UD_MEM, "cannot allocate gstring\n");	 
-  die; 
- }
+ query = g_string_sized_new(STR_L);
  
  /* compose query */
  g_string_sprintf(query, "SELECT * FROM dummy_rec WHERE transaction_id=%ld", tr->transaction_id);
@@ -277,7 +270,7 @@ SQ_row_t *sql_row;
  
  /* in case of an error copy error code and return */ 
  if(sql_err) {
-   ER_perror(FAC_UD, UD_SQL, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
+   LG_log(ud_context, LG_ERROR, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
    die;
  }
  g_string_free(query, TRUE);
@@ -308,6 +301,7 @@ SQ_row_t *sql_row;
 * ndummy                                                    *
 * dummy_id[]                                                *
 * error_script                                              *
+* transaction_id                                            *
 *                                                           *
 * The following fields are filled in by transaction_new()   *
 * thread_upd                                                *
@@ -320,7 +314,7 @@ SQ_row_t *sql_row;
 * 1 - the database was recovered successfully               *
 *                                                           *
 ************************************************************/
-Transaction_t *TR_get_record(SQ_connection_t *sql_connection, long transaction_id)
+Transaction_t *TR_get_record(SQ_connection_t *sql_connection, long transaction_id, LG_context_t *src_ctx)
 {
   Transaction_t *tr;
   /* get the record from SQL table */
@@ -345,7 +339,8 @@ Transaction_t *TR_get_record(SQ_connection_t *sql_connection, long transaction_i
   
 
     class_type = tr_get_class_type(result, row);
-    if ((tr = transaction_new(sql_connection, class_type)) == NULL) die;
+    if ((tr = transaction_new(sql_connection, class_type, src_ctx)) == NULL) die;
+    tr->transaction_id = tr_get_transaction_id(result, row);
     tr->object_id = tr_get_object_id(result, row);
 
     /* Fill in all dummies that were created */
@@ -384,27 +379,24 @@ void TR_delete_record(Transaction_t *tr)
 GString *query;
 int sql_err;
 
-  if(tr->load_pass != 0) return; /* for fast loader just return */
+  if(IS_STANDALONE(tr->mode)) return; /* for loader just return */
   
   /* Delete a record from SQL DB */
-  if ((query = g_string_sized_new(STR_L)) == NULL){ 
-   ER_perror(FAC_UD, UD_MEM, "cannot allocate gstring\n"); 
-   die; 
-  }
+  query = g_string_sized_new(STR_L);
  
   /* compose query */
   g_string_sprintf(query, "DELETE FROM dummy_rec WHERE transaction_id=%ld", tr->transaction_id);
   sql_err=SQ_execute_query(tr->sql_connection, query->str, NULL);
   /* in case of an error copy error code and return */ 
   if(sql_err) {
-   ER_perror(FAC_UD, UD_SQL, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
+   LG_log(ud_context, LG_ERROR, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
    die;
   }
   g_string_sprintf(query, "DELETE FROM transaction_rec WHERE transaction_id=%ld", tr->transaction_id);
   sql_err=SQ_execute_query(tr->sql_connection, query->str, NULL);
   /* in case of an error copy error code and return */ 
   if(sql_err) {
-   ER_perror(FAC_UD, UD_SQL, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
+   LG_log(ud_context, LG_ERROR, "%s[%s]\n", SQ_error(tr->sql_connection), query->str);
    die;
   }
 
@@ -424,7 +416,7 @@ int sql_err;
 * 1 - the database was recovered successfully               *
 *                                                           *
 ************************************************************/
-int TR_recover(SQ_connection_t *sql_connection)
+int TR_recover(SQ_connection_t *sql_connection, ca_dbSource_t *source_hdl, LG_context_t *src_ctx)
 {
 int res;
 Transaction_t * tr;
@@ -435,17 +427,18 @@ char *act_m;
  
  /* Get the transaction record */
  /* XXX for NRTM we may specify transaction_id = 0 ? */
- if ((tr = TR_get_record(sql_connection, TR_LAST)) == NULL) {
+ if ((tr = TR_get_record(sql_connection, TR_LAST, src_ctx)) == NULL) {
     /* everything is clean */
     res = 0;
     fprintf(stderr, "[OK]\n");
-    ER_inf_va(FAC_SV, 0xFFFFFF, "STATUS:[%s]=OK", sql_connection->db);
+    LG_log(ud_context, LG_INFO, "STATUS:[%s]=OK", sql_connection->db);
  }   
  else {/* Not everything was perfect :( */
+    tr->source_hdl = source_hdl; /* this is not filled in by TR_get_record */
     if(ACT_CREATE(tr->action))act_m="CREATE";
      else if(ACT_UPDATE(tr->action))act_m="UPDATE";
       else act_m="DELETE";
-    ER_inf_va(FAC_SV, 0xFFFFFF, "STATUS:[%s]=FAILED [object_id=%ld, sequence_id=%ld, serial_id=%ld, transaction_id=%ld, action=%s]", 
+    LG_log(ud_context, LG_INFO, "STATUS:[%s]=FAILED [object_id=%ld, sequence_id=%ld, serial_id=%ld, transaction_id=%ld, action=%s]", 
                                  sql_connection->db, tr->object_id, tr->sequence_id, tr->serial_id, tr->transaction_id, act_m);
     fprintf(stderr, "[FAILED]\n"
                     "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n"
@@ -457,7 +450,7 @@ char *act_m;
    /************************* R O L L B A C K ***************************/
    if(TS_ROLLBACK(tr->action)) {
      fprintf(stderr, "  STATUS: Rollback\n");
-     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s]=ROLLBACK", sql_connection->db);
+     LG_log(ud_context, LG_INFO, "STATUS:[%s]=ROLLBACK", sql_connection->db);
      
     /* don't rollback the transaction if we were to delete the object, but could not */
      if(!TS_ROLLBACKED(tr->action)){
@@ -465,9 +458,9 @@ char *act_m;
 	     UD_rollback(tr);
 	     CP_ROLLBACK_PASSED(tr->action); TR_update_status(tr);
 	     fprintf(stderr, "[OK]\n");
-	     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Rollback incomplete, completing - OK", sql_connection->db);
+	     LG_log(ud_context, LG_INFO, "STATUS:[%s] Rollback incomplete, completing - OK", sql_connection->db);
      } else  { fprintf(stderr, "  STATUS: Rollback complete [PASSED]\n");
-               ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Rollback complete - PASSED", sql_connection->db); 
+               LG_log(ud_context, LG_INFO, "STATUS:[%s] Rollback complete - PASSED", sql_connection->db); 
 	     }
 	    
      
@@ -476,9 +469,9 @@ char *act_m;
 	     NH_rollback(tr->sql_connection);
 	     CP_ROLLBACK_NH_PASSED(tr->action); TR_update_status(tr);
 	     fprintf(stderr, "[OK]\n");
-	     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] NH rollback incomplete, completing - OK", sql_connection->db);
+	     LG_log(ud_context, LG_INFO, "STATUS:[%s] NH rollback incomplete, completing - OK", sql_connection->db);
      } else  { fprintf(stderr, "  STATUS: NH rollback complete [PASSED]\n");
-               ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] NH rollback complete - PASSED", sql_connection->db); 
+               LG_log(ud_context, LG_INFO, "STATUS:[%s] NH rollback complete - PASSED", sql_connection->db); 
 	     }
      /* In update mode delete TR record. Next time (if any) DBupdate tries to submit, we'll start from scratch */
      /* In NRTM mode we create a serial record even in case of failure (tr->succeeded ==0)*/
@@ -487,7 +480,7 @@ char *act_m;
 	     fprintf(stderr, "  STATUS: Serial does not need to be restored, deleting TR...");
 	     TR_delete_record(tr);
 	     fprintf(stderr, "[OK]\n");
-	     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Serial does not need to be restored, deleting TR - OK", sql_connection->db); 
+	     LG_log(ud_context, LG_INFO, "STATUS:[%s] Serial does not need to be restored, deleting TR - OK", sql_connection->db); 
      } else {
 	     fprintf(stderr, "  STATUS: Cleaning serial, deleting TR...");
 	     if(!TS_CREATED_S(tr->action))
@@ -496,7 +489,7 @@ char *act_m;
 	       UD_commit_serial(tr);
 	     TR_delete_record(tr);
 	     fprintf(stderr, "[OK]\n");
-	     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Cleaning serial, deleting TR - OK", sql_connection->db);
+	     LG_log(ud_context, LG_INFO, "STATUS:[%s] Cleaning serial, deleting TR - OK", sql_connection->db);
      }
       
      res = 1;
@@ -506,7 +499,7 @@ char *act_m;
     /* The ack was sent */
     /* Complete the commit */
     fprintf(stderr, "  STATUS: Commit\n");
-    ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s]=COMMIT", sql_connection->db);
+    LG_log(ud_context, LG_INFO, "STATUS:[%s]=COMMIT", sql_connection->db);
     /* We keep the transaction record in case DBupdate failed */
     /* and requests the same transaction after recovery ? */
     /* Such approach will allow us to avoid 3-way handshaking with DBupdate */
@@ -528,9 +521,9 @@ char *act_m;
 	     UD_delete(tr);
 	     CP_DELETE_PASSED(tr->action); TR_update_status(tr);
              fprintf(stderr, "[OK]\n");
-	     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Delete incomplete, completing - OK", sql_connection->db);
+	     LG_log(ud_context, LG_INFO, "STATUS:[%s] Delete incomplete, completing - OK", sql_connection->db);
      } else  { fprintf(stderr, "  STATUS: Delete complete [PASSED]\n");
-               ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Delete complete - PASSED", sql_connection->db);
+               LG_log(ud_context, LG_INFO, "STATUS:[%s] Delete complete - PASSED", sql_connection->db);
              }
     }
     else { /* update or create */
@@ -540,9 +533,9 @@ char *act_m;
 	     UD_commit_I(tr);
 	     CP_COMMIT_I_PASSED(tr->action); TR_update_status(tr);
              fprintf(stderr, "[OK]\n");
-	     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Commit phase I incomplete, completing - OK", sql_connection->db);
+	     LG_log(ud_context, LG_INFO, "STATUS:[%s] Commit phase I incomplete, completing - OK", sql_connection->db);
      } else  { fprintf(stderr, "  STATUS: Commit phase I complete [PASSED]\n");
-               ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Commit phase I complete - PASSED", sql_connection->db);
+               LG_log(ud_context, LG_INFO, "STATUS:[%s] Commit phase I complete - PASSED", sql_connection->db);
              } 
      /* Check if we passed the second pass of commit */
      if(!TS_COMMITTED_II(tr->action)){
@@ -550,9 +543,9 @@ char *act_m;
 	     UD_commit_II(tr);
 	     CP_COMMIT_II_PASSED(tr->action); TR_update_status(tr);
              fprintf(stderr, "[OK]\n");
-	     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Commit phase II incomplete, completing - OK", sql_connection->db);
+	     LG_log(ud_context, LG_INFO, "STATUS:[%s] Commit phase II incomplete, completing - OK", sql_connection->db);
      } else  { fprintf(stderr, "  STATUS: Commit phase II complete [PASSED]\n");
-               ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Commit phase II complete - PASSED", sql_connection->db);
+               LG_log(ud_context, LG_INFO, "STATUS:[%s] Commit phase II complete - PASSED", sql_connection->db);
              }
     } /* end of delete, create, update specific operations */
     
@@ -562,9 +555,9 @@ char *act_m;
 	     NH_commit(tr->sql_connection);
 	     CP_COMMIT_NH_PASSED(tr->action); TR_update_status(tr);
              fprintf(stderr, "[OK]\n");
-	     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] NH commit incomplete, completing - OK", sql_connection->db);
+	     LG_log(ud_context, LG_INFO, "STATUS:[%s] NH commit incomplete, completing - OK", sql_connection->db);
      } else  { fprintf(stderr, "  STATUS: NH commit complete [PASSED]\n");
-               ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] NH commit complete - PASSED", sql_connection->db);
+               LG_log(ud_context, LG_INFO, "STATUS:[%s] NH commit complete - PASSED", sql_connection->db);
              }
      
      /* create serial file */
@@ -584,20 +577,20 @@ char *act_m;
        CP_CREATE_S_PASSED(tr->action); TR_update_status(tr);
      }
      fprintf(stderr, "[OK]\n");
-     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Serial rollback and restore - OK", sql_connection->db);
+     LG_log(ud_context, LG_INFO, "STATUS:[%s] Serial rollback and restore - OK", sql_connection->db);
      UD_commit_serial(tr);
 
      fprintf(stderr, "  STATUS: Marking TR as clean...");
      TR_mark_clean(tr);
    
      fprintf(stderr, "[OK]\n");
-     ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s] Marking TR as clean - OK", sql_connection->db);
+     LG_log(ud_context, LG_INFO, "STATUS:[%s] Marking TR as clean - OK", sql_connection->db);
      res = 2;
   }
  }
  transaction_free(tr); 
  fprintf(stderr, "  STATUS: The Database is clean \n++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n\n");
- ER_inf_va(FAC_SV, 0xFFFFFF,"STATUS:[%s]=CLEAN", sql_connection->db);
+ LG_log(ud_context, LG_INFO, "STATUS:[%s]=CLEAN", sql_connection->db);
  
  return(res);
 } 
@@ -617,7 +610,8 @@ char *act_m;
 * 1 - the stored transaction was re-played                  *
 *                                                           *
 ************************************************************/
-int TR_check(SQ_connection_t *sql_connection, long transaction_id, int sockfd)
+int 
+TR_check (SQ_connection_t *sql_connection, long transaction_id, int sockfd, LG_context_t *src_ctx)
 {
 Transaction_t * tr;
 
@@ -629,7 +623,7 @@ Transaction_t * tr;
  if(transaction_id <=0) return(0);
  /* Get the transaction record */
  /* XXX for NRTM we may specify transaction_id = 0 ? */
- if ((tr = TR_get_record(sql_connection, transaction_id)) == NULL) return(0); /* everything is clean */
+ if ((tr = TR_get_record(sql_connection, transaction_id, src_ctx)) == NULL) return(0); /* everything is clean */
  
  /* Check if the record is clean (it should be ) */
  /* that means that either the transaction finished normally */
@@ -644,11 +638,11 @@ Transaction_t * tr;
    tr->socket=sockfd;
    g_string_sprintfa(tr->error_script,"I[%ld]: requested transaction was processed before\n", transaction_id);
    UD_ack(tr);
-   ER_inf_va(FAC_UD, ASP_UD_UPDLOG, "[%ld] requested transaction was processed before\n", transaction_id);   
+   LG_log(src_ctx, LG_INFO, "[%ld] requested transaction was processed before\n", transaction_id);   
    transaction_free(tr);
  }
  else {
-	 ER_perror(FAC_UD, UD_SQL, "TR is not clean\n");
+         LG_log(ud_context, LG_SEVERE, "TR is not clean\n");
 	 die; /* the record should be clean */ 
  }
  return(1);
