@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.12 $
+  $Revision: 1.15 $
 
   Functions to interface with RX module (create/update rx-nodes)
 
@@ -11,7 +11,7 @@
   Modification History:
         andrei (17/01/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000,2001,2002                    RIPE NCC
+  Copyright (c) 2000                              RIPE NCC
  
   All Rights Reserved
   
@@ -36,6 +36,7 @@
 /* Function to fill data for radix tree */
 void get_rx_data(void *element_data, void *tr_ptr)
 {
+int err;
 const rpsl_attr_t *attribute = (const rpsl_attr_t *)element_data;
 Transaction_t *tr = (Transaction_t *)tr_ptr;
 int attribute_type = rpsl_get_attr_id(rpsl_attr_get_name(attribute));
@@ -49,8 +50,10 @@ const gchar *attribute_value;
    case A_DN:
     /* it is already clean as we work with the flattened object */
     attribute_value = rpsl_attr_get_value(attribute);
-    if( RP_asc2pack( tr->packptr, attribute_type, attribute_value) != IP_OK ) {
-     dieif( attribute_type != A_DN );  /* DN can be forgiven, but radix should not be updated */
+    if(ERR(err = RP_asc2pack( tr->packptr, attribute_type, attribute_value))) {
+      /* we can also forgive bit inconsistencies */
+      /* DN can be forgiven, but radix should not be updated */
+     dieif( attribute_type != A_DN  );  /* DN can be forgiven, but radix should not be updated */
     } else tr->action |= TA_UPD_RX; /* Update radix in all other cases */
    break; 
    default: break; 
