@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.11 $
+  $Revision: 1.14 $
 
   Utilities (ut). memwrap.h - header file for memory allocation wrappers. 
 
@@ -31,8 +31,9 @@
 #ifndef _MEMWRAP_H
 #define _MEMWRAP_H
 
-#include <erroutines.h>
+/*#include <erroutines.h>*/
 #include <glib.h>
+#include <sys/types.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -54,19 +55,6 @@ char *UT_strdup_real(const char *str, const char *file, int line);
 
 void wr_log_set(int value);
 
-er_ret_t wr_real_malloc(void **ptr, size_t size, const char *file, int line);
-er_ret_t wr_real_calloc(void **ptr, size_t num, size_t size, const char *file, 
-                        int line);
-er_ret_t wr_real_realloc(void **ptr, size_t size, const char *file, int line);
-er_ret_t wr_real_free(void *ptr, const char *file, int line) ;
-char *wr_real_string(const char *text, const char *file, int line);
-
-#define wr_malloc(a,b)    wr_real_malloc((a),(b),     __FILE__ ,__LINE__)
-#define wr_calloc(a,b,c)  wr_real_calloc((a),(b),(c), __FILE__ ,__LINE__)
-#define wr_realloc(a,b)   wr_real_realloc((a),(b),    __FILE__ ,__LINE__)
-#define wr_free(a)        wr_real_free((a),           __FILE__ ,__LINE__)
-#define wr_string(s)      wr_real_string((s),         __FILE__, __LINE__)
-
 void wr_real_clear_list(GList **list, const char *file, int line);
 
 #define wr_clear_list(a)  wr_real_clear_list(a,   __FILE__ ,__LINE__)
