@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.4 $
+  $Revision: 1.6 $
 
   Utilities (ut). numconv.h  - header file for fast numerical conversions
                                (to[?]/from string).
@@ -9,7 +9,7 @@
   Design and implementation by: Marek Bukowy
 
   ******************/ /******************
-  Copyright (c) 1999,2000,2001,2002               RIPE NCC
+  Copyright (c) 1999                              RIPE NCC
  
   All Rights Reserved
   
@@ -29,4 +29,4 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ***************************************/
 
-int ut_dec_2_uns(char *cpy, unsigned *result);
+int ut_dec_2_uns(const char *cpy, unsigned *result);
