@@ -1,5 +1,5 @@
 /******************
-  Copyright (c) 2002                                        RIPE NCC
+  Copyright (c) 2002                              RIPE NCC
 
   All Rights Reserved
 
@@ -19,14 +19,19 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ***************************************/
 
+#ifndef WH_QUERIES_H
+#define WH_QUERIES_H
+
 #include "sk.h"
 
-er_ret_t
-WH_sock(int sock, char *hostname, int port, 
-	    char *query, int maxlines, int timeout);
-er_ret_t
-WH_connect(int *sock, char *hostname, int port);
-er_ret_t
-
+int
 WH_cd_sock(sk_conn_st *out_cd, char *hostname, unsigned  port, 
-	char *query, unsigned  maxlines, unsigned  timeout);
+	char *query, unsigned  maxlines, unsigned  timeout, 
+        int *sk_err);
+
+/* errors */
+#define WH_OK          0
+#define WH_SK_ERR      1
+#define WH_MAXLINES    2
+
+#endif /* WH_QUERIES_H */
