@@ -43,7 +43,7 @@ sub get_certif {
   my $obj = shift @_;
   my $certif = '';
   $obj =~ s/^[\s\n]*//;
-  #print "DEBUG: \$obj is [$obj]\n";
+
   if($obj !~ /^key-cert:/){
 
     return "***Error!\n";
@@ -109,6 +109,23 @@ sub get_certif {
 }
 
 
+# Simple check of sanity for an ASCII dump of a public key
+sub check_sanity {
+
+    my $public_key = shift;
+
+      # make sure the public key has proper start and end marks
+        if (   $public_key !~ /-----BEGIN PGP PUBLIC KEY BLOCK-----/
+                || $public_key !~ /-----END PGP PUBLIC KEY BLOCK-----/){
+              return 0; # return false
+                }
+
+                  # no problem encountered, return 1
+                    return 1;
+
+}
+
+
 
 
 # sub closeDBHandle: closes DB handle 
@@ -187,9 +204,17 @@ unless(($rc) or ($stHandle->errstr)) {
       my($i, @values); 
       while ( ((@values) = $stHandle->fetchrow_array)){
         foreach $i (@values) {
-           #print "[$i]\n";
+
            $certif = &get_certif($i); 
-           #print $certif,"\n";
+           # perform a simple sanity check. If does not pass, do not print out
+           # the $certif to STDOUT
+           if(!&check_sanity($certif)){
+             print STDERR "ERROR: This object does not pass sanity check:\n";
+             print STDERR "$i\n";
+             print STDERR "Will continue to process other objects.\n";
+             next;
+           }
+
            $i =~ /^.*(PGPKEY-.{8})/i;
            $keyid = $1;
            print "\nNext: $keyid\n\n$certif\n";
